← Back to team overview

kicad-developers team mailing list archive

Re: Pad import/export/push and modedit mirror

 

I have attached a patch that renames this. It contains three commits
for easier review.

You should be able to apply with git am rename_pad_settings_tool.patch.

2017-01-25 19:13 GMT+01:00 Nick Østergaard <oe.nick@xxxxxxxxx>:
> I have always had the feeling that import and export was a bit strange
> user of terminology. I do find it hard to find some better words, but
> what about copy and apply?
>
> Import becomes apply and export becomes copy?
>
> (and then swap the order of them in the list for a more logical ordering)
>
> 2017-01-25 15:35 GMT+01:00 Wayne Stambaugh <stambaughw@xxxxxxxxx>:
>> @Orson, would you please take a look at this patch when you get a
>> chance.  They both look good to me.
>>
>> I did see a few coding policy issues.  Mostly this:
>>
>> +        if ( selection[0]->Type() == PCB_PAD_T )
>>
>> which should be:
>>
>> +        if( selection[0]->Type() == PCB_PAD_T )
>>
>> @John, please clean these up and resubmit the patches when you get a chance.
>>
>> Thanks,
>>
>> Wayne
>>
>> On 1/25/2017 2:39 AM, John Beard wrote:
>>> Sorry, attached the wrong version of the "import export" patch - this
>>> is the correct sequence.
>>>
>>> On Wed, Jan 25, 2017 at 12:41 AM, John Beard <john.j.beard@xxxxxxxxx> wrote:
>>>> Hi,
>>>>
>>>> Here are two patches for outstanding GAL functionality: pad
>>>> import/export/push and modedit mirroring.
>>>>
>>>> Pad "push" is what I termed global edit, since I think that describes
>>>> the action of taking a reference and "pushing" it to a filtered subset
>>>> of other pads. I am happy to keep the old name too, if that's
>>>> preferred.
>>>>
>>>> I have implemented in a new PAD_TOOL GAL tool as I think there could
>>>> be more pad-only function in future that can all stick together in
>>>> there.
>>>>
>>>> Let me know if there are any suggestions!
>>>>
>>>> John
>>>>
>>>>
>>>> _______________________________________________
>>>> Mailing list: https://launchpad.net/~kicad-developers
>>>> Post to     : kicad-developers@xxxxxxxxxxxxxxxxxxx
>>>> Unsubscribe : https://launchpad.net/~kicad-developers
>>>> More help   : https://help.launchpad.net/ListHelp
>>
>> _______________________________________________
>> Mailing list: https://launchpad.net/~kicad-developers
>> Post to     : kicad-developers@xxxxxxxxxxxxxxxxxxx
>> Unsubscribe : https://launchpad.net/~kicad-developers
>> More help   : https://help.launchpad.net/ListHelp
From 62bc57bcea22d2cabe5eee78ee2463ed00fbd81d Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Nick=20=C3=98stergaard?= <oe.nick@xxxxxxxxx>
Date: Fri, 3 Feb 2017 19:56:56 +0100
Subject: [PATCH 1/3] Rename pad copy actions in the pad tool

Import becomes apply and export becomes copy.

The term "push" to apply settings globally has not been renamed.

Swap the order of the copy and apply in the context menu.
---
 pcbnew/edit.cpp                 |  8 +++---
 pcbnew/modedit.cpp              |  8 +++---
 pcbnew/modedit_onclick.cpp      | 10 ++++----
 pcbnew/onrightclick.cpp         | 15 +++++------
 pcbnew/pcbnew_id.h              |  4 +--
 pcbnew/tools/common_actions.cpp | 18 ++++++-------
 pcbnew/tools/common_actions.h   |  4 +--
 pcbnew/tools/pad_tool.cpp       | 57 ++++++++++++++++++++---------------------
 pcbnew/tools/pad_tool.h         |  8 +++---
 9 files changed, 65 insertions(+), 67 deletions(-)

diff --git a/pcbnew/edit.cpp b/pcbnew/edit.cpp
index 12ebcb3bc..c5e345392 100644
--- a/pcbnew/edit.cpp
+++ b/pcbnew/edit.cpp
@@ -99,8 +99,8 @@ void PCB_EDIT_FRAME::Process_Special_Functions( wxCommandEvent& event )
     case ID_POPUP_PCB_SELECT_CU_LAYER_AND_PLACE_BLIND_BURIED_VIA:
     case ID_POPUP_PCB_PLACE_MICROVIA:
     case ID_POPUP_PCB_SWITCH_TRACK_POSTURE:
-    case ID_POPUP_PCB_IMPORT_PAD_SETTINGS:
-    case ID_POPUP_PCB_EXPORT_PAD_SETTINGS:
+    case ID_POPUP_PCB_APPLY_PAD_SETTINGS:
+    case ID_POPUP_PCB_COPY_PAD_SETTINGS:
     case ID_POPUP_PCB_GLOBAL_IMPORT_PAD_SETTINGS:
     case ID_POPUP_PCB_STOP_CURRENT_EDGE_ZONE:
     case ID_POPUP_PCB_DELETE_ZONE_LAST_CREATED_CORNER:
@@ -938,7 +938,7 @@ void PCB_EDIT_FRAME::Process_Special_Functions( wxCommandEvent& event )
         m_canvas->MoveCursorToCrossHair();
         break;
 
-    case ID_POPUP_PCB_IMPORT_PAD_SETTINGS:
+    case ID_POPUP_PCB_APPLY_PAD_SETTINGS:
         m_canvas->MoveCursorToCrossHair();
         SaveCopyInUndoList( GetCurItem()->GetParent(), UR_CHANGED );
         Import_Pad_Settings( (D_PAD*) GetCurItem(), true );
@@ -949,7 +949,7 @@ void PCB_EDIT_FRAME::Process_Special_Functions( wxCommandEvent& event )
         DlgGlobalChange_PadSettings( (D_PAD*) GetCurItem(), true );
         break;
 
-    case ID_POPUP_PCB_EXPORT_PAD_SETTINGS:
+    case ID_POPUP_PCB_COPY_PAD_SETTINGS:
         m_canvas->MoveCursorToCrossHair();
         Export_Pad_Settings( (D_PAD*) GetCurItem() );
         break;
diff --git a/pcbnew/modedit.cpp b/pcbnew/modedit.cpp
index 5eea2fb1a..bbce20c1e 100644
--- a/pcbnew/modedit.cpp
+++ b/pcbnew/modedit.cpp
@@ -217,8 +217,8 @@ void FOOTPRINT_EDIT_FRAME::Process_Special_Functions( wxCommandEvent& event )
     case ID_POPUP_PCB_ROTATE_MODULE_CLOCKWISE:
     case ID_POPUP_PCB_ROTATE_MODULE_COUNTERCLOCKWISE:
     case ID_POPUP_PCB_EDIT_TEXTMODULE:
-    case ID_POPUP_PCB_IMPORT_PAD_SETTINGS:
-    case ID_POPUP_PCB_EXPORT_PAD_SETTINGS:
+    case ID_POPUP_PCB_APPLY_PAD_SETTINGS:
+    case ID_POPUP_PCB_COPY_PAD_SETTINGS:
     case ID_POPUP_PCB_GLOBAL_IMPORT_PAD_SETTINGS:
     case ID_POPUP_PCB_STOP_CURRENT_DRAWING:
     case ID_POPUP_MODEDIT_EDIT_BODY_ITEM:
@@ -649,7 +649,7 @@ void FOOTPRINT_EDIT_FRAME::Process_Special_Functions( wxCommandEvent& event )
         createArray();
         break;
 
-    case ID_POPUP_PCB_IMPORT_PAD_SETTINGS:
+    case ID_POPUP_PCB_APPLY_PAD_SETTINGS:
         SaveCopyInUndoList( GetBoard()->m_Modules, UR_CHANGED );
         m_canvas->MoveCursorToCrossHair();
         Import_Pad_Settings( (D_PAD*) GetScreen()->GetCurItem(), true );
@@ -662,7 +662,7 @@ void FOOTPRINT_EDIT_FRAME::Process_Special_Functions( wxCommandEvent& event )
         m_canvas->MoveCursorToCrossHair();
         break;
 
-    case ID_POPUP_PCB_EXPORT_PAD_SETTINGS:
+    case ID_POPUP_PCB_COPY_PAD_SETTINGS:
         m_canvas->MoveCursorToCrossHair();
         Export_Pad_Settings( (D_PAD*) GetScreen()->GetCurItem() );
         break;
diff --git a/pcbnew/modedit_onclick.cpp b/pcbnew/modedit_onclick.cpp
index 97c1c090a..a3577259b 100644
--- a/pcbnew/modedit_onclick.cpp
+++ b/pcbnew/modedit_onclick.cpp
@@ -310,10 +310,10 @@ bool FOOTPRINT_EDIT_FRAME::OnRightClick( const wxPoint& MousePos, wxMenu* PopMen
 
             msg = AddHotkeyName( _("Edit Pad" ), g_Module_Editor_Hokeys_Descr, HK_EDIT_ITEM );
             AddMenuItem( PopMenu, ID_POPUP_PCB_EDIT_PAD, msg, KiBitmap( options_pad_xpm ) );
-            AddMenuItem( PopMenu, ID_POPUP_PCB_IMPORT_PAD_SETTINGS,
-                         _( "New Pad Settings" ), KiBitmap( options_new_pad_xpm ) );
-            AddMenuItem( PopMenu, ID_POPUP_PCB_EXPORT_PAD_SETTINGS,
-                         _( "Export Pad Settings" ), KiBitmap( export_options_pad_xpm ) );
+            AddMenuItem( PopMenu, ID_POPUP_PCB_COPY_PAD_SETTINGS,
+                         _( "Copy Pad Settings" ), KiBitmap( copy_pad_settings_xpm ) );
+            AddMenuItem( PopMenu, ID_POPUP_PCB_APPLY_PAD_SETTINGS,
+                         _( "Apply Pad Settings" ), KiBitmap( apply_pad_settings_xpm ) );
             msg = AddHotkeyName( _("Delete Pad" ), g_Module_Editor_Hokeys_Descr, HK_DELETE );
             AddMenuItem( PopMenu, ID_POPUP_PCB_DELETE_PAD, msg, KiBitmap( delete_pad_xpm ) );
 
@@ -331,7 +331,7 @@ bool FOOTPRINT_EDIT_FRAME::OnRightClick( const wxPoint& MousePos, wxMenu* PopMen
             {
                 PopMenu->AppendSeparator();
                 AddMenuItem( PopMenu, ID_POPUP_PCB_GLOBAL_IMPORT_PAD_SETTINGS,
-                             _( "Global Pad Settings" ), KiBitmap( global_options_pad_xpm ) );
+                             _( "Push Pad Settings" ), KiBitmap( global_options_pad_xpm ) );
             }
 
             break;
diff --git a/pcbnew/onrightclick.cpp b/pcbnew/onrightclick.cpp
index f5ed5d065..06305d500 100644
--- a/pcbnew/onrightclick.cpp
+++ b/pcbnew/onrightclick.cpp
@@ -940,17 +940,16 @@ void PCB_EDIT_FRAME::createPopUpMenuForFpPads( D_PAD* Pad, wxMenu* menu )
     AddMenuItem( sub_menu_Pad, ID_POPUP_PCB_EDIT_PAD, msg, KiBitmap( options_pad_xpm ) );
     sub_menu_Pad->AppendSeparator();
 
-    AddMenuItem( sub_menu_Pad, ID_POPUP_PCB_IMPORT_PAD_SETTINGS,
-                 _( "Copy Current Settings to this Pad" ),
+    AddMenuItem( sub_menu_Pad, ID_POPUP_PCB_COPY_PAD_SETTINGS,
+                 _( "Copy Pad Settings" ),
                  wxEmptyString,
-                 KiBitmap( options_new_pad_xpm ) );
-    AddMenuItem( sub_menu_Pad, ID_POPUP_PCB_EXPORT_PAD_SETTINGS,
-                 _( "Copy this Pad Settings to Current Settings" ),
+                 KiBitmap( copy_pad_settings_xpm ) );
+    AddMenuItem( sub_menu_Pad, ID_POPUP_PCB_APPLY_PAD_SETTINGS,
+                 _( "Apply Pad Settings" ),
                  wxEmptyString,
-                 KiBitmap( export_options_pad_xpm ) );
-
+                 KiBitmap( apply_pad_settings_xpm ) );
     AddMenuItem( sub_menu_Pad, ID_POPUP_PCB_GLOBAL_IMPORT_PAD_SETTINGS,
-                 _( "Edit All Pads" ),
+                 _( "Push Pad Settings" ),
                  _( "Copy this pad's settings to all pads in this footprint (or similar footprints)" ),
                  KiBitmap( global_options_pad_xpm ) );
     sub_menu_Pad->AppendSeparator();
diff --git a/pcbnew/pcbnew_id.h b/pcbnew/pcbnew_id.h
index 8e98979e7..9c7ce80aa 100644
--- a/pcbnew/pcbnew_id.h
+++ b/pcbnew/pcbnew_id.h
@@ -146,8 +146,8 @@ enum pcbnew_ids
     ID_POPUP_PCB_PLACE_MICROVIA,
     ID_POPUP_PCB_SWITCH_TRACK_POSTURE,
 
-    ID_POPUP_PCB_IMPORT_PAD_SETTINGS,
-    ID_POPUP_PCB_EXPORT_PAD_SETTINGS,
+    ID_POPUP_PCB_APPLY_PAD_SETTINGS,
+    ID_POPUP_PCB_COPY_PAD_SETTINGS,
 
     ID_POPUP_PCB_EDIT_TRACKSEG,
     ID_POPUP_PCB_EDIT_TRACK_MNU,
diff --git a/pcbnew/tools/common_actions.cpp b/pcbnew/tools/common_actions.cpp
index 498d86355..be7b9a104 100644
--- a/pcbnew/tools/common_actions.cpp
+++ b/pcbnew/tools/common_actions.cpp
@@ -469,23 +469,23 @@ TOOL_ACTION COMMON_ACTIONS::moduleTextOutlines( "pcbnew.ModuleEditor.textOutline
        "", "" );
 
 // Pad tools
-TOOL_ACTION COMMON_ACTIONS::exportPadSettings(
-        "pcbnew.PadTool.ExportPadSettings",
+TOOL_ACTION COMMON_ACTIONS::copyPadSettings(
+        "pcbnew.PadTool.CopyPadSettings",
         AS_GLOBAL, 0,
-        _( "Export Pad Settings" ), _( "Copy current pad's settings to the board design settings" ),
-        export_options_pad_xpm );
+        _( "Copy Pad Settings" ), _( "Copy current pad's settings to the board design settings" ),
+        copy_pad_settings_xpm );
 
-TOOL_ACTION COMMON_ACTIONS::importPadSettings(
-        "pcbnew.PadTool.ImportPadSettings",
+TOOL_ACTION COMMON_ACTIONS::applyPadSettings(
+        "pcbnew.PadTool.ApplyPadSettings",
         AS_GLOBAL, 0,
-        _( "Import Pad Settings" ), _( "Copy the board design settings pad properties to the current pad" ),
-        options_new_pad_xpm );
+        _( "Apply Pad Settings" ), _( "Copy the board design settings pad properties to the current pad" ),
+        apply_pad_settings_xpm );
 
 TOOL_ACTION COMMON_ACTIONS::pushPadSettings(
         "pcbnew.PadTool.PushPadSettings",
         AS_GLOBAL, 0,
         _( "Push Pad Settings" ), _( "Copy the current pad settings to other pads" ),
-        global_options_pad_xpm );
+        push_pad_settings_xpm );
 
 // Cursor control
 TOOL_ACTION COMMON_ACTIONS::cursorUp( "pcbnew.Control.cursorUp",
diff --git a/pcbnew/tools/common_actions.h b/pcbnew/tools/common_actions.h
index b8167cf3c..3f2478075 100644
--- a/pcbnew/tools/common_actions.h
+++ b/pcbnew/tools/common_actions.h
@@ -280,10 +280,10 @@ public:
 
     // Pad tools
     /// Copy the selected pad's settings to the board design settings
-    static TOOL_ACTION exportPadSettings;
+    static TOOL_ACTION copyPadSettings;
 
     /// Copy the pad settings in the board design settings to the selected pad
-    static TOOL_ACTION importPadSettings;
+    static TOOL_ACTION applyPadSettings;
 
     /// Copy the current pad's settings to other pads in the module or on the board
     static TOOL_ACTION pushPadSettings;
-- 
2.11.0


From c4a36e4b89b01ebedc1ba2d2cdeb9788fa4db2c4 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Nick=20=C3=98stergaard?= <oe.nick@xxxxxxxxx>
Date: Fri, 3 Feb 2017 21:47:01 +0100
Subject: [PATCH 2/3] Rename bitmaps to match the new pad tool naming

---
 bitmaps_png/CMakeLists.txt                                          | 6 +++---
 bitmaps_png/sources/{options_new_pad.svg => apply_pad_settings.svg} | 0
 .../sources/{export_options_pad.svg => copy_pad_settings.svg}       | 0
 .../sources/{global_options_pad.svg => push_pad_settings.svg}       | 0
 include/bitmaps.h                                                   | 6 +++---
 pcbnew/modedit_onclick.cpp                                          | 2 +-
 pcbnew/onrightclick.cpp                                             | 2 +-
 pcbnew/tools/common_actions.cpp                                     | 2 +-
 8 files changed, 9 insertions(+), 9 deletions(-)
 rename bitmaps_png/sources/{options_new_pad.svg => apply_pad_settings.svg} (100%)
 rename bitmaps_png/sources/{export_options_pad.svg => copy_pad_settings.svg} (100%)
 rename bitmaps_png/sources/{global_options_pad.svg => push_pad_settings.svg} (100%)

diff --git a/bitmaps_png/CMakeLists.txt b/bitmaps_png/CMakeLists.txt
index 41097a394..8dae66fcf 100644
--- a/bitmaps_png/CMakeLists.txt
+++ b/bitmaps_png/CMakeLists.txt
@@ -136,6 +136,7 @@ set( BMAPS_MID
     annotate_down_right
     annotate_right_down
     annotate
+    apply_pad_settings
     array_line
     array_module
     array_pad
@@ -171,6 +172,7 @@ set( BMAPS_MID
     copycomponent
     copy_button
     copy_library
+    copy_pad_settings
     copper_layers_setup
     cursor_shape
     cursor
@@ -241,7 +243,6 @@ set( BMAPS_MID
     export_idf
     export_footprint_names
     export_module
-    export_options_pad
     export
     fabrication
     file_footprint
@@ -267,7 +268,6 @@ set( BMAPS_MID
     glabel2label
     glabel2text
     gl_change
-    global_options_pad
     green
     grid_select
     grid_select_axis
@@ -412,7 +412,6 @@ set( BMAPS_MID
     options_arc
     options_circle
     options_module
-    options_new_pad
     options_pad
     options_pinsheet
     options_pin
@@ -468,6 +467,7 @@ set( BMAPS_MID
     ps_diff_pair_tune_phase
     ps_diff_pair_via_gap
     ps_tune_length
+    push_pad_settings
     py_script
     ratsnest
     read_setup
diff --git a/bitmaps_png/sources/options_new_pad.svg b/bitmaps_png/sources/apply_pad_settings.svg
similarity index 100%
rename from bitmaps_png/sources/options_new_pad.svg
rename to bitmaps_png/sources/apply_pad_settings.svg
diff --git a/bitmaps_png/sources/export_options_pad.svg b/bitmaps_png/sources/copy_pad_settings.svg
similarity index 100%
rename from bitmaps_png/sources/export_options_pad.svg
rename to bitmaps_png/sources/copy_pad_settings.svg
diff --git a/bitmaps_png/sources/global_options_pad.svg b/bitmaps_png/sources/push_pad_settings.svg
similarity index 100%
rename from bitmaps_png/sources/global_options_pad.svg
rename to bitmaps_png/sources/push_pad_settings.svg
diff --git a/include/bitmaps.h b/include/bitmaps.h
index 886b1836b..f33dd3ce3 100644
--- a/include/bitmaps.h
+++ b/include/bitmaps.h
@@ -103,6 +103,7 @@ EXTERN_BITMAP( annotate_down_right_xpm )
 EXTERN_BITMAP( annotate_right_down_xpm )
 EXTERN_BITMAP( annotate_xpm )
 EXTERN_BITMAP( align_items_xpm )
+EXTERN_BITMAP( apply_pad_settings_xpm )
 EXTERN_BITMAP( array_line_xpm )
 EXTERN_BITMAP( array_module_xpm )
 EXTERN_BITMAP( array_pad_xpm )
@@ -142,6 +143,7 @@ EXTERN_BITMAP( copyblock_xpm )
 EXTERN_BITMAP( copycomponent_xpm )
 EXTERN_BITMAP( copy_button_xpm )
 EXTERN_BITMAP( copy_library_xpm )
+EXTERN_BITMAP( copy_pad_settings_xpm )
 EXTERN_BITMAP( create_cmp_file_xpm )
 EXTERN_BITMAP( cursor_shape_xpm )
 EXTERN_BITMAP( cursor_xpm )
@@ -214,7 +216,6 @@ EXTERN_BITMAP( export_dsn_xpm )
 EXTERN_BITMAP( export_idf_xpm )
 EXTERN_BITMAP( export_footprint_names_xpm )
 EXTERN_BITMAP( export_module_xpm )
-EXTERN_BITMAP( export_options_pad_xpm )
 EXTERN_BITMAP( export_xpm )
 EXTERN_BITMAP( fabrication_xpm )
 EXTERN_BITMAP( file_footprint_xpm )
@@ -240,7 +241,6 @@ EXTERN_BITMAP( general_ratsnest_xpm )
 EXTERN_BITMAP( glabel2label_xpm )
 EXTERN_BITMAP( glabel2text_xpm )
 EXTERN_BITMAP( gl_change_xpm )
-EXTERN_BITMAP( global_options_pad_xpm )
 EXTERN_BITMAP( green_xpm )
 EXTERN_BITMAP( grid_select_axis_xpm )
 EXTERN_BITMAP( grid_select_xpm )
@@ -398,7 +398,6 @@ EXTERN_BITMAP( options_all_vias_xpm )
 EXTERN_BITMAP( options_arc_xpm )
 EXTERN_BITMAP( options_circle_xpm )
 EXTERN_BITMAP( options_module_xpm )
-EXTERN_BITMAP( options_new_pad_xpm )
 EXTERN_BITMAP( options_pad_xpm )
 EXTERN_BITMAP( options_pinsheet_xpm )
 EXTERN_BITMAP( options_pin_xpm )
@@ -468,6 +467,7 @@ EXTERN_BITMAP( polar_coord_xpm )
 EXTERN_BITMAP( post_compo_xpm )
 EXTERN_BITMAP( post_drill_xpm )
 EXTERN_BITMAP( post_module_xpm )
+EXTERN_BITMAP( push_pad_settings_xpm )
 EXTERN_BITMAP( preference_xpm )
 EXTERN_BITMAP( print_button_xpm )
 EXTERN_BITMAP( ps_router_xpm )
diff --git a/pcbnew/modedit_onclick.cpp b/pcbnew/modedit_onclick.cpp
index a3577259b..60ad2bc81 100644
--- a/pcbnew/modedit_onclick.cpp
+++ b/pcbnew/modedit_onclick.cpp
@@ -331,7 +331,7 @@ bool FOOTPRINT_EDIT_FRAME::OnRightClick( const wxPoint& MousePos, wxMenu* PopMen
             {
                 PopMenu->AppendSeparator();
                 AddMenuItem( PopMenu, ID_POPUP_PCB_GLOBAL_IMPORT_PAD_SETTINGS,
-                             _( "Push Pad Settings" ), KiBitmap( global_options_pad_xpm ) );
+                             _( "Push Pad Settings" ), KiBitmap( push_pad_settings_xpm ) );
             }
 
             break;
diff --git a/pcbnew/onrightclick.cpp b/pcbnew/onrightclick.cpp
index 06305d500..f0027fc44 100644
--- a/pcbnew/onrightclick.cpp
+++ b/pcbnew/onrightclick.cpp
@@ -951,7 +951,7 @@ void PCB_EDIT_FRAME::createPopUpMenuForFpPads( D_PAD* Pad, wxMenu* menu )
     AddMenuItem( sub_menu_Pad, ID_POPUP_PCB_GLOBAL_IMPORT_PAD_SETTINGS,
                  _( "Push Pad Settings" ),
                  _( "Copy this pad's settings to all pads in this footprint (or similar footprints)" ),
-                 KiBitmap( global_options_pad_xpm ) );
+                 KiBitmap( push_pad_settings_xpm ) );
     sub_menu_Pad->AppendSeparator();
 
     AddMenuItem( sub_menu_Pad, ID_POPUP_PCB_DELETE_PAD, _( "Delete" ), KiBitmap( delete_pad_xpm ) );
diff --git a/pcbnew/tools/common_actions.cpp b/pcbnew/tools/common_actions.cpp
index be7b9a104..8b8260d04 100644
--- a/pcbnew/tools/common_actions.cpp
+++ b/pcbnew/tools/common_actions.cpp
@@ -94,7 +94,7 @@ TOOL_ACTION COMMON_ACTIONS::copySettingsToPads( "pcbnew.InteractiveEdit.copySett
 TOOL_ACTION COMMON_ACTIONS::globalEditPads( "pcbnew.InteractiveEdit.globalPadEdit",
         AS_GLOBAL, 0,
         _( "Global Pad Edition" ),
-        _( "Changes pad properties globally." ), global_options_pad_xpm );
+        _( "Changes pad properties globally." ), push_pad_settings_xpm );
 
 TOOL_ACTION COMMON_ACTIONS::editActivate( "pcbnew.InteractiveEdit",
         AS_GLOBAL, TOOL_ACTION::LegacyHotKey( HK_MOVE_ITEM ),
-- 
2.11.0


From c244561425fdbb41ee1dfc88fbb3e12b0049a09c Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Nick=20=C3=98stergaard?= <oe.nick@xxxxxxxxx>
Date: Fri, 3 Feb 2017 23:00:45 +0100
Subject: [PATCH 3/3] Regenerate the cpp_26/{apply,copy,push}_pad_settings.cpp

---
 bitmaps_png/cpp_26/apply_pad_settings.cpp | 100 ++++++++++++++++++++++++++++++
 bitmaps_png/cpp_26/copy_pad_settings.cpp  |  92 +++++++++++++++++++++++++++
 bitmaps_png/cpp_26/export_options_pad.cpp |  92 ---------------------------
 bitmaps_png/cpp_26/global_options_pad.cpp |  86 -------------------------
 bitmaps_png/cpp_26/options_new_pad.cpp    |  99 -----------------------------
 bitmaps_png/cpp_26/push_pad_settings.cpp  |  88 ++++++++++++++++++++++++++
 6 files changed, 280 insertions(+), 277 deletions(-)
 create mode 100644 bitmaps_png/cpp_26/apply_pad_settings.cpp
 create mode 100644 bitmaps_png/cpp_26/copy_pad_settings.cpp
 delete mode 100644 bitmaps_png/cpp_26/export_options_pad.cpp
 delete mode 100644 bitmaps_png/cpp_26/global_options_pad.cpp
 delete mode 100644 bitmaps_png/cpp_26/options_new_pad.cpp
 create mode 100644 bitmaps_png/cpp_26/push_pad_settings.cpp

diff --git a/bitmaps_png/cpp_26/apply_pad_settings.cpp b/bitmaps_png/cpp_26/apply_pad_settings.cpp
new file mode 100644
index 000000000..d402216c3
--- /dev/null
+++ b/bitmaps_png/cpp_26/apply_pad_settings.cpp
@@ -0,0 +1,100 @@
+
+/* Do not modify this file, it was automatically generated by the
+ * PNG2cpp CMake script, using a *.png file as input.
+ */
+
+#include <bitmaps.h>
+
+static const unsigned char png[] = {
+ 0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d, 0x49, 0x48, 0x44, 0x52,
+ 0x00, 0x00, 0x00, 0x1a, 0x00, 0x00, 0x00, 0x1a, 0x08, 0x06, 0x00, 0x00, 0x00, 0xa9, 0x4a, 0x4c,
+ 0xce, 0x00, 0x00, 0x05, 0x31, 0x49, 0x44, 0x41, 0x54, 0x48, 0xc7, 0xb5, 0x56, 0x69, 0x4c, 0x54,
+ 0x67, 0x14, 0x3d, 0xae, 0x94, 0x2e, 0xd8, 0x04, 0x01, 0x0b, 0xa2, 0x82, 0xd3, 0x91, 0x48, 0x24,
+ 0x5a, 0x25, 0xc5, 0x05, 0x4c, 0x5b, 0xe8, 0x0c, 0x5a, 0x2c, 0xa4, 0x90, 0x94, 0x06, 0x9b, 0x6a,
+ 0x9a, 0xc6, 0x42, 0xc5, 0x25, 0x25, 0x2a, 0x22, 0x8e, 0x4b, 0xd2, 0xa4, 0x7f, 0x2c, 0x0d, 0xfd,
+ 0x61, 0x8b, 0xb5, 0x41, 0x4d, 0x13, 0x77, 0x90, 0x11, 0x89, 0xc1, 0x18, 0x22, 0x51, 0x2a, 0x03,
+ 0x44, 0x82, 0x85, 0x28, 0x14, 0x15, 0x50, 0xa0, 0x33, 0x38, 0xcc, 0xb0, 0xc8, 0x32, 0xb7, 0xe7,
+ 0xbd, 0x81, 0x96, 0xa1, 0x88, 0x84, 0xb4, 0x5f, 0x72, 0x32, 0x2f, 0xef, 0x7e, 0xef, 0x9e, 0xef,
+ 0xdc, 0x7b, 0xbe, 0x9b, 0x01, 0x9e, 0xb7, 0x0e, 0xc3, 0x1f, 0x06, 0xac, 0x20, 0x34, 0xc4, 0x74,
+ 0xbe, 0x99, 0x82, 0x17, 0xac, 0x8b, 0x17, 0xb1, 0xe9, 0xc2, 0x05, 0x34, 0x5e, 0xbe, 0x0c, 0xb7,
+ 0xf1, 0x77, 0x1a, 0xf0, 0x32, 0x0e, 0x22, 0x9d, 0xbf, 0x2d, 0xc8, 0xc4, 0x20, 0xf6, 0xa0, 0x07,
+ 0x3b, 0x30, 0x80, 0xaf, 0x60, 0xc5, 0x17, 0xf8, 0x05, 0xef, 0x23, 0x80, 0xbb, 0xa6, 0x8e, 0x45,
+ 0x7a, 0xfa, 0x34, 0xdc, 0xf3, 0xf3, 0xd1, 0x74, 0xf3, 0x26, 0xe4, 0xfc, 0x79, 0xa4, 0xe2, 0x05,
+ 0x0a, 0x7e, 0x27, 0x2c, 0x24, 0xe9, 0xe1, 0xaf, 0xfc, 0x8d, 0xbd, 0xe8, 0xc3, 0x16, 0x74, 0x22,
+ 0x91, 0x84, 0xa1, 0xd8, 0xc4, 0xdd, 0xaf, 0x8f, 0x26, 0xa3, 0x92, 0x8c, 0x8a, 0x0a, 0xc8, 0x93,
+ 0x27, 0x90, 0x82, 0x02, 0xfc, 0x99, 0x97, 0x87, 0xd7, 0xc6, 0x52, 0xf2, 0x2a, 0x51, 0xa7, 0x92,
+ 0x1c, 0x80, 0xc3, 0x85, 0x64, 0x24, 0x76, 0xa2, 0x0b, 0x1b, 0x61, 0xd7, 0xac, 0x45, 0xf2, 0xe1,
+ 0xc3, 0x88, 0x39, 0x7b, 0x16, 0x49, 0x3c, 0xfd, 0x5e, 0x96, 0xec, 0xc7, 0xc2, 0x42, 0xd8, 0xcd,
+ 0x66, 0x48, 0x6f, 0x2f, 0xa4, 0xaa, 0x0a, 0x42, 0xe2, 0xab, 0xc4, 0x3e, 0x22, 0xf1, 0xdc, 0x39,
+ 0x1e, 0x6f, 0x88, 0xe8, 0x10, 0x61, 0xc6, 0xfe, 0xe7, 0x10, 0x8c, 0xc4, 0x97, 0xe8, 0x5c, 0x9e,
+ 0x8a, 0x1a, 0x92, 0xd8, 0x4a, 0x4a, 0x20, 0x0d, 0x0d, 0x90, 0xf6, 0x76, 0x88, 0xcd, 0x06, 0xe9,
+ 0xef, 0x87, 0x88, 0x40, 0xec, 0x76, 0x88, 0xc5, 0x02, 0x79, 0xf0, 0x00, 0x52, 0x5d, 0x0d, 0xa1,
+ 0x3a, 0x61, 0x71, 0x31, 0x8d, 0x04, 0x1d, 0x4c, 0xe2, 0x5a, 0xae, 0x4c, 0x62, 0x37, 0x6c, 0xd8,
+ 0x37, 0x4a, 0xe1, 0x7e, 0xf6, 0x2e, 0x09, 0x83, 0x91, 0x09, 0x48, 0x3b, 0x73, 0x06, 0x6d, 0x26,
+ 0x93, 0x33, 0xe9, 0xe0, 0xa0, 0x93, 0x64, 0x18, 0xdd, 0xdd, 0x90, 0xa6, 0x26, 0x48, 0x51, 0x91,
+ 0xaa, 0xee, 0x07, 0x45, 0x4d, 0x08, 0xd1, 0x3b, 0x8a, 0xc4, 0x81, 0xb5, 0x34, 0x05, 0xb0, 0x1e,
+ 0xcb, 0xb0, 0x81, 0x64, 0x7d, 0x2e, 0xf1, 0xcf, 0x61, 0x47, 0x38, 0xbe, 0x5d, 0xb5, 0x0a, 0x1b,
+ 0x99, 0xa4, 0xb6, 0xb2, 0xd2, 0xa9, 0x68, 0x98, 0x64, 0x60, 0x00, 0xf2, 0xe8, 0x11, 0xc4, 0x68,
+ 0x84, 0x83, 0x71, 0x83, 0xb3, 0x6c, 0x07, 0xa0, 0xe3, 0x29, 0xad, 0x2e, 0x89, 0xbe, 0x46, 0x3b,
+ 0x23, 0x1f, 0x10, 0xcb, 0x88, 0xe9, 0x8c, 0x5f, 0x75, 0x89, 0x27, 0x53, 0xe9, 0xbb, 0x38, 0xce,
+ 0x58, 0xf4, 0xf1, 0xe3, 0xd8, 0x59, 0x5e, 0xee, 0x54, 0xa0, 0xa0, 0xb3, 0xd3, 0x59, 0xc2, 0xe6,
+ 0x66, 0x55, 0x49, 0xf9, 0x3f, 0x46, 0x38, 0x88, 0x95, 0xfc, 0xd8, 0xee, 0x92, 0x68, 0x0f, 0x9e,
+ 0xb1, 0xa0, 0x31, 0x8c, 0x6a, 0x54, 0x77, 0x19, 0xf0, 0x87, 0x4b, 0x7c, 0x0b, 0x89, 0x22, 0x90,
+ 0xcd, 0x98, 0xee, 0xd4, 0x29, 0xe4, 0xd6, 0xd6, 0x42, 0x5a, 0x5b, 0x21, 0x35, 0x35, 0x90, 0xdb,
+ 0xb7, 0x9d, 0x24, 0x4a, 0xdf, 0x68, 0xf7, 0x2e, 0x83, 0x41, 0xbd, 0x0e, 0xaa, 0x11, 0x3c, 0x88,
+ 0x3e, 0xb5, 0xf6, 0x23, 0x93, 0xa5, 0xb1, 0x6f, 0x29, 0x30, 0xf2, 0x7d, 0xdd, 0xbf, 0x0c, 0xb1,
+ 0x89, 0xfb, 0x83, 0xe9, 0x41, 0x20, 0x21, 0x35, 0x15, 0xf5, 0x47, 0x8e, 0x40, 0x68, 0x0e, 0xa1,
+ 0xfb, 0x6e, 0xd0, 0x85, 0x3f, 0xb3, 0xf9, 0xcf, 0xca, 0xca, 0x20, 0x57, 0xae, 0xa8, 0xef, 0xdf,
+ 0x1c, 0x69, 0xef, 0x7c, 0x64, 0xf0, 0x94, 0x86, 0x09, 0xb8, 0x6e, 0x37, 0xfb, 0x99, 0x80, 0xc7,
+ 0x8a, 0x1a, 0x0f, 0x8f, 0x57, 0xbe, 0xd3, 0xeb, 0x75, 0xa2, 0xd3, 0x45, 0x39, 0xf4, 0xfa, 0x99,
+ 0xdf, 0x8c, 0x98, 0x10, 0xfe, 0x44, 0x16, 0x4b, 0xd7, 0x4d, 0x7c, 0x34, 0x92, 0x28, 0x88, 0x27,
+ 0xef, 0x21, 0x59, 0xdf, 0x78, 0x24, 0xee, 0x9f, 0xb8, 0x3b, 0x66, 0xbd, 0x35, 0x6b, 0x90, 0x9d,
+ 0x3b, 0xc4, 0xaf, 0xa2, 0xfc, 0xfc, 0xde, 0xb8, 0x71, 0xf2, 0xe4, 0x49, 0x39, 0x7a, 0xf4, 0xa8,
+ 0xcc, 0x9d, 0x3b, 0xf7, 0xa7, 0xa1, 0x6c, 0xde, 0x7c, 0x2e, 0xf6, 0xf5, 0xf5, 0xdd, 0x40, 0x65,
+ 0xbe, 0x24, 0x5a, 0xee, 0x7a, 0x69, 0x33, 0x11, 0xc7, 0x72, 0xf5, 0xa9, 0x97, 0x72, 0x8c, 0xfb,
+ 0x34, 0x33, 0x7e, 0xe6, 0xb3, 0x15, 0x2b, 0x57, 0xc8, 0xf6, 0x1d, 0xdb, 0x07, 0x99, 0xe8, 0xf1,
+ 0xbc, 0x79, 0xf3, 0x5a, 0x63, 0x63, 0x63, 0x6d, 0x55, 0x55, 0x55, 0x52, 0x59, 0x59, 0x29, 0xd1,
+ 0xd1, 0xd1, 0xd6, 0x05, 0x0b, 0x16, 0xd4, 0x2f, 0x5e, 0xbc, 0xf8, 0x71, 0x6e, 0x6e, 0xae, 0x63,
+ 0xf5, 0xea, 0xd5, 0x1d, 0x1e, 0x1e, 0x1e, 0xeb, 0xc6, 0x1e, 0x43, 0x7b, 0x11, 0x86, 0x6d, 0x1c,
+ 0x43, 0x9b, 0x69, 0x86, 0x14, 0x3a, 0x31, 0x95, 0x26, 0x51, 0x46, 0xcf, 0x66, 0xaa, 0x5d, 0x0f,
+ 0x8b, 0x36, 0x48, 0x6b, 0xbb, 0x7e, 0xfd, 0xba, 0x5c, 0xba, 0x74, 0x49, 0xca, 0xca, 0xca, 0xa4,
+ 0xa5, 0xa5, 0x45, 0xcc, 0x66, 0xb3, 0x74, 0x75, 0x75, 0xd1, 0x71, 0xdd, 0x72, 0xf7, 0xee, 0x5d,
+ 0xb9, 0x7f, 0xff, 0x3e, 0x0d, 0x71, 0x5b, 0xb4, 0x5a, 0x6d, 0x13, 0x33, 0xfa, 0x8c, 0x37, 0x5a,
+ 0xa7, 0x32, 0xf1, 0x3b, 0x88, 0xc5, 0x11, 0xac, 0xe3, 0x75, 0x8e, 0xe2, 0x30, 0x5d, 0xce, 0xce,
+ 0xb8, 0x61, 0x83, 0xa7, 0xa7, 0x67, 0x7e, 0x7a, 0x7a, 0xba, 0x3c, 0x7c, 0xf8, 0x90, 0x2e, 0x6b,
+ 0x55, 0x51, 0x5c, 0x5c, 0x2c, 0xd7, 0xae, 0x5d, 0xa3, 0xcb, 0xda, 0x79, 0x71, 0x2d, 0xd2, 0xd6,
+ 0xd6, 0x26, 0x29, 0x29, 0x29, 0x03, 0xdc, 0xbb, 0x07, 0x13, 0x58, 0x53, 0x86, 0xa6, 0xf4, 0x4b,
+ 0x84, 0x17, 0xe1, 0x4b, 0x78, 0x6a, 0x34, 0x9a, 0x7a, 0xe5, 0xb4, 0x8a, 0x8a, 0x8a, 0x8a, 0x0a,
+ 0x09, 0x0d, 0x0d, 0x6d, 0x5d, 0xb8, 0x70, 0x61, 0x41, 0x60, 0x60, 0x60, 0x51, 0x58, 0x58, 0x58,
+ 0x5b, 0x79, 0x79, 0x39, 0xad, 0xdd, 0x2c, 0x25, 0x25, 0x25, 0xc2, 0x32, 0xd6, 0xf1, 0x9b, 0xc0,
+ 0xa1, 0x3c, 0x13, 0x5a, 0xc1, 0xfe, 0xfe, 0xfe, 0xf7, 0x82, 0x82, 0x82, 0x5a, 0xb6, 0x6e, 0xdd,
+ 0xda, 0xd5, 0xd1, 0xd1, 0x21, 0x3d, 0x3d, 0x3d, 0x12, 0x17, 0x17, 0x67, 0x61, 0x0f, 0xde, 0x1e,
+ 0xde, 0x44, 0x05, 0xef, 0xc5, 0xc7, 0xc7, 0x3f, 0x6d, 0x68, 0x68, 0xe0, 0x7d, 0xaa, 0x91, 0x5d,
+ 0xbb, 0x76, 0xf5, 0x87, 0x87, 0x87, 0x9b, 0x7d, 0x7c, 0x7c, 0x5a, 0x87, 0xee, 0xe3, 0x0b, 0x97,
+ 0x8e, 0x04, 0xfd, 0x75, 0x75, 0x75, 0x62, 0xb5, 0x5a, 0x55, 0x12, 0x9b, 0xcd, 0x26, 0x4b, 0x97,
+ 0x2e, 0x7d, 0x34, 0xba, 0x0a, 0x21, 0x21, 0x21, 0xcd, 0xd5, 0xd5, 0xd5, 0x6a, 0x8f, 0x0a, 0x0b,
+ 0x0b, 0xe5, 0xc4, 0x89, 0x13, 0xb4, 0xbe, 0xae, 0x97, 0xb1, 0x88, 0x89, 0x10, 0x69, 0x03, 0x02,
+ 0x02, 0x7e, 0xa3, 0xa2, 0xfa, 0xe4, 0xe4, 0x64, 0x9b, 0x42, 0xa6, 0xf4, 0x22, 0x31, 0x31, 0xd1,
+ 0x3a, 0x7b, 0xf6, 0xec, 0x98, 0xe1, 0x4d, 0x7c, 0xfe, 0x38, 0x21, 0x21, 0xa1, 0xf3, 0xd6, 0xad,
+ 0x5b, 0x6a, 0xcf, 0x22, 0x22, 0x22, 0x9e, 0xce, 0x99, 0x33, 0xc7, 0x44, 0xfc, 0x3a, 0x54, 0xfa,
+ 0x89, 0xaf, 0x45, 0x8b, 0x16, 0xd5, 0xdf, 0xb9, 0x73, 0x47, 0x6d, 0xb8, 0xc9, 0x64, 0x52, 0x92,
+ 0x99, 0xe7, 0xcf, 0x9f, 0x6f, 0x22, 0x2a, 0xd6, 0xac, 0x59, 0xd3, 0x51, 0x50, 0x50, 0xa0, 0x9a,
+ 0x23, 0x27, 0x27, 0x47, 0xfc, 0xfc, 0xfc, 0x6a, 0x31, 0xd9, 0xc5, 0xd3, 0x7d, 0x9f, 0x91, 0x91,
+ 0xe1, 0x50, 0x1a, 0xde, 0xd8, 0xd8, 0xa8, 0xda, 0x59, 0x29, 0x51, 0x5e, 0x5e, 0x9e, 0x28, 0xb6,
+ 0x2f, 0x2a, 0x2a, 0xe2, 0x7c, 0xcb, 0x97, 0xcc, 0xcc, 0x4c, 0xf1, 0xf6, 0xf6, 0x2e, 0x9d, 0x14,
+ 0x89, 0x9b, 0x9b, 0x9b, 0x66, 0xc9, 0x92, 0x25, 0x4f, 0x14, 0xb7, 0x29, 0x27, 0x57, 0xca, 0xa3,
+ 0xa8, 0x2a, 0x2d, 0x2d, 0x55, 0x9f, 0x8d, 0x46, 0xa3, 0x1c, 0x3b, 0x76, 0x4c, 0xd2, 0xd2, 0xd2,
+ 0x38, 0xb5, 0x2f, 0x48, 0x4c, 0x4c, 0x8c, 0xcd, 0xcb, 0xcb, 0x6b, 0xdb, 0x64, 0xd4, 0x7c, 0x16,
+ 0x19, 0x19, 0xf9, 0x94, 0x7d, 0xea, 0xe5, 0x78, 0xb9, 0x47, 0xfb, 0x3e, 0xd0, 0xeb, 0xf5, 0x9d,
+ 0xd9, 0xd9, 0xd9, 0xa2, 0x8c, 0xa1, 0xa8, 0xa8, 0x28, 0x1b, 0xdf, 0x37, 0xd2, 0x65, 0x46, 0xda,
+ 0xde, 0x42, 0xbb, 0x5b, 0x58, 0xbe, 0x4f, 0x27, 0xa5, 0x8a, 0x36, 0xdf, 0xcc, 0x44, 0xca, 0xf0,
+ 0x9c, 0xa6, 0x60, 0xc6, 0x8c, 0x19, 0xa9, 0x49, 0x49, 0x49, 0x83, 0x59, 0x59, 0x59, 0xc2, 0x83,
+ 0x94, 0x0c, 0xff, 0x61, 0x71, 0x77, 0x77, 0x5f, 0xc5, 0x7d, 0x89, 0xf8, 0x0f, 0x97, 0x36, 0x38,
+ 0x38, 0xd8, 0x4e, 0x0b, 0x3b, 0x58, 0xa6, 0x74, 0xfc, 0x8f, 0x4b, 0x51, 0x16, 0x4f, 0x7c, 0xa8,
+ 0xdc, 0xd9, 0xf1, 0x36, 0xfe, 0x05, 0x42, 0x5d, 0x1a, 0x8b, 0x5b, 0xdd, 0xcb, 0x64, 0x00, 0x00,
+ 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82,
+};
+
+const BITMAP_OPAQUE apply_pad_settings_xpm[1] = {{ png, sizeof( png ), "apply_pad_settings_xpm" }};
+
+//EOF
diff --git a/bitmaps_png/cpp_26/copy_pad_settings.cpp b/bitmaps_png/cpp_26/copy_pad_settings.cpp
new file mode 100644
index 000000000..8df040af9
--- /dev/null
+++ b/bitmaps_png/cpp_26/copy_pad_settings.cpp
@@ -0,0 +1,92 @@
+
+/* Do not modify this file, it was automatically generated by the
+ * PNG2cpp CMake script, using a *.png file as input.
+ */
+
+#include <bitmaps.h>
+
+static const unsigned char png[] = {
+ 0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d, 0x49, 0x48, 0x44, 0x52,
+ 0x00, 0x00, 0x00, 0x1a, 0x00, 0x00, 0x00, 0x1a, 0x08, 0x06, 0x00, 0x00, 0x00, 0xa9, 0x4a, 0x4c,
+ 0xce, 0x00, 0x00, 0x04, 0xb0, 0x49, 0x44, 0x41, 0x54, 0x48, 0xc7, 0xd5, 0x56, 0x6b, 0x48, 0x9b,
+ 0x67, 0x14, 0x8e, 0x55, 0x3b, 0x2f, 0x4d, 0x93, 0x18, 0x63, 0xb7, 0x49, 0x19, 0x1d, 0x9d, 0x6b,
+ 0x77, 0x61, 0x17, 0xc2, 0x60, 0x83, 0x96, 0x16, 0xc6, 0xba, 0x3f, 0x83, 0xb2, 0x3a, 0xd9, 0xe8,
+ 0x0a, 0x13, 0xd1, 0xb1, 0xfd, 0xe8, 0xa0, 0x32, 0xa8, 0xa2, 0x56, 0x9c, 0x5d, 0x74, 0x8a, 0x1a,
+ 0xc5, 0x7a, 0x9b, 0xd6, 0x4b, 0xa2, 0xa9, 0x1a, 0xbc, 0xd5, 0xc6, 0x24, 0x56, 0x1b, 0x6f, 0x8d,
+ 0x6e, 0x6a, 0x04, 0x63, 0xbd, 0x46, 0x93, 0x79, 0x69, 0xac, 0x1a, 0x4d, 0xbc, 0x50, 0x6f, 0xef,
+ 0x9e, 0x57, 0xf2, 0x59, 0x67, 0x75, 0x45, 0x65, 0x3f, 0xf6, 0xc2, 0xc3, 0xc7, 0xfb, 0xe6, 0xbc,
+ 0xe7, 0xf9, 0xce, 0x39, 0xcf, 0x39, 0x5f, 0x58, 0xac, 0xff, 0xdb, 0x4a, 0x48, 0x48, 0xf0, 0x88,
+ 0x8e, 0x8e, 0x3e, 0xfe, 0x9f, 0x92, 0x24, 0x27, 0x27, 0x1f, 0x95, 0x4a, 0xa5, 0x39, 0x65, 0x65,
+ 0x65, 0xa5, 0x20, 0xf3, 0x7e, 0xf1, 0x8d, 0x3f, 0x59, 0xce, 0x5e, 0xf7, 0xb9, 0x57, 0x04, 0x2a,
+ 0xae, 0x58, 0x50, 0xc3, 0xcd, 0xf1, 0xac, 0xe0, 0xfc, 0xec, 0x71, 0xcd, 0x95, 0xbe, 0xe5, 0x61,
+ 0xc0, 0x61, 0xb7, 0x6b, 0x29, 0x29, 0x29, 0xd7, 0x57, 0x56, 0x56, 0xf4, 0xeb, 0xeb, 0xeb, 0x8f,
+ 0xb3, 0xb2, 0xb2, 0x8a, 0x23, 0x23, 0x23, 0xdd, 0x76, 0xe5, 0x78, 0xb9, 0xce, 0xe3, 0x6d, 0xaf,
+ 0x3a, 0x5e, 0xaf, 0x57, 0x3d, 0x8f, 0x6c, 0x85, 0x40, 0xc5, 0x9b, 0x3f, 0x1a, 0xee, 0x16, 0x06,
+ 0x13, 0x3e, 0x70, 0x68, 0xa7, 0xbb, 0xf1, 0xf1, 0xf1, 0x17, 0xa7, 0xa7, 0xa7, 0x6b, 0x08, 0xd6,
+ 0xf2, 0xf2, 0xf2, 0x23, 0xec, 0xb3, 0x77, 0x7c, 0xb1, 0x63, 0xca, 0x63, 0xee, 0x82, 0x7a, 0x5e,
+ 0xcf, 0x76, 0x92, 0x4d, 0x32, 0x35, 0x77, 0xd5, 0xe5, 0xdc, 0x61, 0x11, 0x4c, 0x5f, 0xd9, 0x85,
+ 0xcc, 0x21, 0x3d, 0x3d, 0xfd, 0x37, 0x44, 0x64, 0xa2, 0x64, 0x16, 0x8b, 0xa5, 0x39, 0x22, 0x22,
+ 0xe2, 0xc6, 0x73, 0x56, 0x5e, 0xf7, 0x79, 0x3f, 0x30, 0x4e, 0x3f, 0xbe, 0xfb, 0x91, 0x55, 0xd7,
+ 0xa7, 0x9b, 0x33, 0x98, 0x0c, 0x0b, 0x57, 0xca, 0x2f, 0xcf, 0x30, 0xe7, 0xdc, 0x04, 0xf6, 0x30,
+ 0x4c, 0xfd, 0x00, 0x77, 0xab, 0xd5, 0xca, 0x4f, 0x4b, 0x4b, 0xbb, 0x90, 0x9a, 0x9a, 0xfa, 0x45,
+ 0x52, 0x52, 0xd2, 0x25, 0x44, 0xf0, 0x0d, 0x10, 0x5c, 0x51, 0x51, 0xa1, 0x00, 0xcf, 0x2a, 0x25,
+ 0xeb, 0xee, 0xee, 0xae, 0x0b, 0x08, 0x08, 0xf8, 0xea, 0x9f, 0x44, 0xb5, 0xbc, 0x0c, 0xc6, 0x61,
+ 0xd5, 0xc3, 0xca, 0x69, 0x62, 0x5f, 0xe6, 0x27, 0xe6, 0x25, 0xe6, 0x9c, 0x2f, 0xe3, 0xd8, 0x60,
+ 0x1a, 0x0b, 0x08, 0x66, 0x67, 0x67, 0x5f, 0xd7, 0x6a, 0xb5, 0x9f, 0x0d, 0x0f, 0x0f, 0x07, 0x4d,
+ 0x4e, 0x4e, 0xde, 0x9c, 0x99, 0x99, 0x91, 0xce, 0xcf, 0xcf, 0x37, 0x2c, 0x2e, 0x2e, 0xb6, 0x21,
+ 0x2a, 0xab, 0xfd, 0xfa, 0x3a, 0x04, 0xa2, 0x09, 0x0c, 0x0c, 0x7c, 0xff, 0x19, 0x91, 0x9a, 0x77,
+ 0x8b, 0x71, 0x58, 0xd8, 0x20, 0xdd, 0x24, 0xa2, 0x51, 0x6d, 0x12, 0x49, 0x39, 0x56, 0x98, 0xfe,
+ 0x0e, 0xbc, 0x3a, 0x36, 0x36, 0x76, 0x1c, 0x3f, 0xbf, 0x07, 0x7c, 0x07, 0x88, 0x01, 0x0d, 0xc0,
+ 0x10, 0x6c, 0x2e, 0x9b, 0xcd, 0xd6, 0x09, 0xa2, 0xb0, 0x67, 0x44, 0x0a, 0xde, 0xb7, 0x8c, 0xc3,
+ 0x53, 0x8a, 0x93, 0x4f, 0xef, 0x34, 0xc9, 0xa6, 0x95, 0x7f, 0x28, 0x2d, 0xe7, 0x2b, 0xcf, 0x5a,
+ 0x99, 0x73, 0xce, 0x0d, 0x77, 0x23, 0x4c, 0x6f, 0x51, 0xdd, 0x4c, 0x4d, 0x4d, 0x9d, 0x96, 0xc9,
+ 0x64, 0x3f, 0x41, 0xce, 0x91, 0xd5, 0xd5, 0xd5, 0x49, 0xb5, 0xb5, 0xb5, 0xb7, 0x35, 0x1a, 0x8d,
+ 0xbc, 0xb9, 0xb9, 0xb9, 0x0a, 0xfe, 0x67, 0x28, 0xc9, 0xda, 0xda, 0xda, 0xe3, 0x90, 0x90, 0x10,
+ 0x75, 0x50, 0x50, 0xd0, 0x16, 0x05, 0x9e, 0x63, 0x39, 0x09, 0x14, 0xdc, 0xc6, 0xdd, 0xc4, 0xe0,
+ 0x59, 0xc9, 0x79, 0xea, 0xe8, 0xed, 0x78, 0x0f, 0x96, 0xd7, 0x00, 0x1e, 0xfc, 0x1c, 0xca, 0xc8,
+ 0xc8, 0x70, 0x8b, 0x8b, 0x8b, 0x73, 0x47, 0x9d, 0x8e, 0xc4, 0xc6, 0xc6, 0xb2, 0xd1, 0xb0, 0x9f,
+ 0x0f, 0x0d, 0x0d, 0xdd, 0xb3, 0x07, 0xb3, 0x54, 0x50, 0x50, 0xf0, 0xc0, 0xdf, 0xdf, 0xff, 0xf9,
+ 0x06, 0xe6, 0xfc, 0xc2, 0x39, 0xc1, 0x2f, 0xe2, 0x68, 0xb7, 0x93, 0xf0, 0x25, 0x1c, 0xab, 0xb3,
+ 0xd0, 0xe9, 0x01, 0x4c, 0xc4, 0xc0, 0x87, 0x80, 0xf3, 0xf6, 0xbb, 0x31, 0x31, 0x31, 0x9c, 0xf2,
+ 0xf2, 0x72, 0x09, 0x55, 0x37, 0xad, 0x4d, 0x7d, 0x7d, 0xbd, 0x2a, 0x3c, 0x3c, 0xfc, 0xcc, 0x6e,
+ 0xad, 0x44, 0x75, 0xcf, 0x75, 0xfb, 0xf2, 0xa5, 0x1f, 0xd9, 0xdf, 0xbb, 0x29, 0xdc, 0x83, 0x5c,
+ 0xb5, 0x2e, 0xe7, 0x9d, 0xd5, 0x2c, 0x47, 0xd6, 0x6d, 0x9c, 0x87, 0x02, 0x42, 0xc0, 0x95, 0xe9,
+ 0x8f, 0xc4, 0xc4, 0xc4, 0xd3, 0xa5, 0xa5, 0xa5, 0x99, 0xf9, 0xf9, 0xf9, 0xc1, 0x88, 0x2a, 0x18,
+ 0xa9, 0xd2, 0xd3, 0x50, 0x10, 0x95, 0x32, 0x2a, 0x2a, 0xea, 0xeb, 0x17, 0xcd, 0x06, 0x07, 0xbb,
+ 0x33, 0x4f, 0xe0, 0x24, 0xf0, 0x2e, 0xf0, 0x1a, 0x4d, 0x17, 0x8d, 0x04, 0x1d, 0xcf, 0x65, 0x0c,
+ 0xf3, 0xf2, 0xf2, 0xa2, 0xfa, 0xfb, 0xfb, 0x49, 0x43, 0x43, 0x83, 0x9e, 0x4a, 0x7c, 0x62, 0x62,
+ 0xa2, 0x02, 0xea, 0x6b, 0x11, 0x89, 0x44, 0x91, 0x7b, 0x1d, 0x61, 0xb4, 0x31, 0x9d, 0x98, 0x08,
+ 0x20, 0xd5, 0x70, 0xb5, 0x5a, 0x3d, 0x8e, 0xdc, 0x27, 0xe4, 0xe6, 0xe6, 0x5e, 0x45, 0xf1, 0xbb,
+ 0x4c, 0x26, 0x13, 0x01, 0x99, 0x4d, 0xa9, 0x54, 0x66, 0xe6, 0xe4, 0xe4, 0x94, 0xb7, 0xb6, 0xb6,
+ 0x4e, 0xb5, 0xb4, 0xb4, 0xb4, 0xa1, 0xc7, 0xbc, 0xf7, 0x3d, 0x38, 0x0b, 0x0b, 0x0b, 0x25, 0x1d,
+ 0x1d, 0x1d, 0xa4, 0xa7, 0xa7, 0x87, 0xa6, 0x87, 0x40, 0xe2, 0x04, 0x63, 0x87, 0xa0, 0x77, 0x36,
+ 0x80, 0x69, 0x40, 0x10, 0x11, 0xe9, 0xec, 0xec, 0x34, 0x62, 0x4a, 0xbc, 0xb1, 0x6f, 0x22, 0xaa,
+ 0xac, 0xc6, 0xc6, 0xc6, 0x31, 0xa3, 0xd1, 0x48, 0xcc, 0x66, 0x33, 0xc1, 0x74, 0x20, 0x0b, 0x0b,
+ 0x0b, 0x1b, 0x40, 0x03, 0x13, 0x48, 0x7e, 0xe3, 0x1c, 0x35, 0x13, 0x1d, 0xe8, 0x53, 0x90, 0x9d,
+ 0x9d, 0x7d, 0x7d, 0x74, 0x74, 0x74, 0x23, 0x0a, 0x34, 0x22, 0x41, 0x8a, 0x94, 0x38, 0xbb, 0x0c,
+ 0xb5, 0x45, 0x0f, 0x0e, 0x0e, 0x4e, 0x8c, 0x8f, 0x8f, 0x13, 0x9a, 0x4a, 0xa4, 0xb7, 0x03, 0x35,
+ 0x3b, 0xfb, 0xaf, 0x13, 0x7c, 0xa7, 0x85, 0x9a, 0x84, 0xb6, 0xb5, 0xb5, 0x19, 0x07, 0x06, 0x06,
+ 0x16, 0xe7, 0xe6, 0xe6, 0xc8, 0xd2, 0xd2, 0x12, 0x9d, 0x63, 0x03, 0x70, 0xe4, 0xc4, 0xd8, 0xc8,
+ 0xe5, 0xf2, 0x9b, 0x94, 0x44, 0xaf, 0xd7, 0x13, 0x9d, 0x4e, 0x47, 0xd0, 0xb8, 0x04, 0x0d, 0xdd,
+ 0xb7, 0x27, 0xa2, 0xa2, 0xa2, 0xa2, 0x28, 0x38, 0x78, 0x42, 0x23, 0xa1, 0x69, 0xa2, 0x29, 0xeb,
+ 0xea, 0xea, 0x7a, 0x04, 0xa2, 0xcd, 0x29, 0x0e, 0xa1, 0x84, 0xf5, 0xf5, 0xf5, 0x11, 0xcc, 0x3f,
+ 0xaa, 0xc2, 0x35, 0x4c, 0x8c, 0xbf, 0xa0, 0xca, 0x96, 0x3d, 0xa7, 0x8d, 0xa6, 0x01, 0x62, 0x48,
+ 0x66, 0x6a, 0x01, 0x29, 0xaf, 0xd5, 0xd4, 0xd4, 0xc8, 0xf1, 0x65, 0x3d, 0x03, 0xb5, 0x5d, 0x45,
+ 0xc4, 0x26, 0x1a, 0x05, 0xd2, 0x46, 0xd0, 0x5b, 0x3d, 0x5b, 0x5f, 0x62, 0xcf, 0x0b, 0x0d, 0xca,
+ 0x6d, 0x6f, 0x6f, 0x1f, 0x63, 0x6a, 0x61, 0x30, 0x18, 0x68, 0x0a, 0x69, 0x74, 0x04, 0x52, 0x27,
+ 0x0a, 0x85, 0x82, 0x60, 0xee, 0x51, 0x31, 0xc8, 0x0f, 0x24, 0x06, 0xd4, 0xe1, 0xd7, 0x91, 0x91,
+ 0x91, 0x55, 0x80, 0xf4, 0xf6, 0xf6, 0x12, 0x90, 0x92, 0xa6, 0xa6, 0xa6, 0x8d, 0x28, 0xaa, 0xaa,
+ 0xaa, 0x08, 0x7a, 0x89, 0xa8, 0x54, 0x2a, 0xba, 0xb7, 0xa1, 0x8f, 0x2e, 0xed, 0x9b, 0x88, 0xce,
+ 0x32, 0x38, 0xb7, 0xa1, 0x66, 0xc5, 0xc8, 0x7f, 0x31, 0xf6, 0xc3, 0x98, 0xda, 0x34, 0x8a, 0x75,
+ 0x89, 0x44, 0xf2, 0x10, 0xf3, 0x2e, 0x14, 0xb5, 0xc2, 0xb6, 0xda, 0x90, 0x99, 0x99, 0xf9, 0xc9,
+ 0x41, 0x82, 0xe2, 0xfa, 0xf9, 0xf9, 0x5d, 0xc0, 0xf3, 0x03, 0x3a, 0xef, 0x7d, 0x7d, 0x7d, 0x63,
+ 0x51, 0x27, 0x52, 0x52, 0x52, 0x62, 0x61, 0xb3, 0xd9, 0x17, 0x71, 0x46, 0x9d, 0xbf, 0x25, 0x14,
+ 0x0a, 0xdf, 0xc4, 0xd3, 0xe5, 0x20, 0x44, 0x8e, 0xf6, 0x3f, 0x28, 0x27, 0x80, 0x77, 0x7c, 0x7c,
+ 0x7c, 0x3e, 0xc5, 0xa7, 0x42, 0x2b, 0x16, 0x8b, 0xef, 0xda, 0xa7, 0xfa, 0x29, 0x80, 0x8e, 0x9e,
+ 0x23, 0x3b, 0x5d, 0xfe, 0x1b, 0x6d, 0x62, 0x51, 0xcf, 0xbe, 0xb0, 0xd3, 0xd3, 0x00, 0x00, 0x00,
+ 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82,
+};
+
+const BITMAP_OPAQUE copy_pad_settings_xpm[1] = {{ png, sizeof( png ), "copy_pad_settings_xpm" }};
+
+//EOF
diff --git a/bitmaps_png/cpp_26/export_options_pad.cpp b/bitmaps_png/cpp_26/export_options_pad.cpp
deleted file mode 100644
index 1e2bcf0f7..000000000
--- a/bitmaps_png/cpp_26/export_options_pad.cpp
+++ /dev/null
@@ -1,92 +0,0 @@
-
-/* Do not modify this file, it was automatically generated by the
- * PNG2cpp CMake script, using a *.png file as input.
- */
-
-#include <bitmaps.h>
-
-static const unsigned char png[] = {
- 0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d, 0x49, 0x48, 0x44, 0x52,
- 0x00, 0x00, 0x00, 0x1a, 0x00, 0x00, 0x00, 0x1a, 0x08, 0x06, 0x00, 0x00, 0x00, 0xa9, 0x4a, 0x4c,
- 0xce, 0x00, 0x00, 0x04, 0xad, 0x49, 0x44, 0x41, 0x54, 0x48, 0xc7, 0xbd, 0x96, 0x6b, 0x4c, 0x9b,
- 0x55, 0x18, 0xc7, 0x8b, 0x85, 0x08, 0x85, 0x97, 0xf6, 0x65, 0xc0, 0x32, 0x25, 0xc6, 0x91, 0x25,
- 0x9b, 0xba, 0xc4, 0x6c, 0x21, 0x31, 0xfa, 0x65, 0xea, 0x5c, 0xb2, 0x68, 0xa6, 0x31, 0x18, 0x3f,
- 0x90, 0x2c, 0xd9, 0x07, 0x6d, 0x32, 0x11, 0x03, 0xc4, 0xa8, 0x59, 0x8c, 0x6b, 0x10, 0x0a, 0x94,
- 0xfb, 0x1d, 0x2c, 0x97, 0x72, 0x87, 0x92, 0x72, 0x19, 0xd0, 0x1b, 0xb0, 0x02, 0x65, 0x84, 0x5b,
- 0x09, 0x73, 0xc0, 0x20, 0x88, 0x30, 0x14, 0xe4, 0x52, 0x28, 0x20, 0x50, 0x42, 0xd6, 0x1e, 0xff,
- 0x07, 0xfb, 0x02, 0xb2, 0xa1, 0x01, 0xd4, 0x37, 0xf9, 0xa7, 0xed, 0xc9, 0x7b, 0x9e, 0xdf, 0x79,
- 0xae, 0xa7, 0x3c, 0x42, 0x08, 0xef, 0xff, 0xd0, 0xbf, 0x66, 0x28, 0x33, 0x33, 0x93, 0x8d, 0x8d,
- 0x8d, 0xf5, 0xfb, 0x4f, 0x41, 0x31, 0x31, 0x31, 0xc2, 0xd2, 0xd2, 0xd2, 0x82, 0x9a, 0x9a, 0x1a,
- 0x55, 0x54, 0x54, 0xd4, 0xa9, 0x7f, 0x04, 0xf1, 0x94, 0x3c, 0xbe, 0x6f, 0x8b, 0xe8, 0xba, 0x6f,
- 0x33, 0x9b, 0xed, 0xa3, 0x63, 0xcb, 0x7d, 0xee, 0x08, 0xbf, 0x16, 0x7c, 0x25, 0x78, 0x8e, 0xc7,
- 0xe3, 0x39, 0x43, 0x4e, 0x07, 0x81, 0x32, 0x32, 0x32, 0x3e, 0xb7, 0xd9, 0x6c, 0x43, 0x76, 0xbb,
- 0x7d, 0x2e, 0x27, 0x27, 0x47, 0x99, 0x98, 0x98, 0xe8, 0x76, 0x20, 0xc8, 0xcb, 0xe0, 0xe5, 0xe7,
- 0x63, 0x10, 0xf5, 0xf8, 0x1a, 0x58, 0xb2, 0x57, 0x3e, 0x5a, 0x91, 0x45, 0x78, 0x4b, 0xf0, 0x09,
- 0x40, 0x9e, 0x07, 0xc1, 0x92, 0x92, 0x92, 0xde, 0x5b, 0x58, 0x58, 0x50, 0xe3, 0x3b, 0xd9, 0xda,
- 0xda, 0x7a, 0x28, 0x93, 0xc9, 0xe4, 0xfb, 0xdf, 0xdd, 0xf5, 0xc4, 0xc0, 0x1a, 0xf7, 0x43, 0x76,
- 0x60, 0x6a, 0xd6, 0xea, 0x72, 0xd1, 0xe5, 0x53, 0x6c, 0x16, 0x1d, 0x04, 0xcb, 0xce, 0xce, 0x96,
- 0xc1, 0xab, 0x29, 0x0a, 0x5b, 0x5a, 0x5a, 0xea, 0x94, 0x48, 0x24, 0xdf, 0x3d, 0x01, 0x3a, 0xd9,
- 0xca, 0x5e, 0xe3, 0x8c, 0x9e, 0xd3, 0x9f, 0xd9, 0xac, 0xbb, 0x57, 0x6b, 0xee, 0x7e, 0xd0, 0xbd,
- 0x7c, 0xa5, 0xfe, 0xad, 0x15, 0x6e, 0x5d, 0x28, 0x71, 0x7f, 0x00, 0xc8, 0x25, 0xc8, 0x15, 0x86,
- 0x84, 0x30, 0x7c, 0x19, 0x21, 0xbb, 0x9a, 0x96, 0x96, 0xf6, 0x7e, 0x72, 0x72, 0x72, 0x60, 0x42,
- 0x42, 0x42, 0x70, 0x75, 0x75, 0xb5, 0x0e, 0xf6, 0x1e, 0x53, 0xd8, 0xe0, 0xe0, 0xa0, 0x21, 0x34,
- 0x34, 0xf4, 0xa3, 0xbf, 0x80, 0x7c, 0xef, 0xb2, 0x32, 0xce, 0x60, 0x8e, 0x36, 0x6b, 0x9e, 0x38,
- 0x9e, 0xa1, 0xd1, 0xc1, 0x1d, 0x90, 0x57, 0x91, 0xe7, 0x12, 0x20, 0xb7, 0x20, 0xaf, 0xe5, 0xe5,
- 0xe5, 0xd3, 0xfd, 0xfd, 0xfd, 0xef, 0x4c, 0x4c, 0x4c, 0x88, 0xe7, 0xe7, 0xe7, 0xa5, 0x2b, 0x2b,
- 0x2b, 0x65, 0x1b, 0x1b, 0x1b, 0xf7, 0x36, 0x37, 0x37, 0x4d, 0xc8, 0xd3, 0xaa, 0x63, 0xbb, 0x1d,
- 0xc5, 0xd1, 0x1a, 0x1e, 0x1e, 0xfe, 0xea, 0x2e, 0x48, 0x2f, 0x8a, 0xe0, 0x0c, 0x4a, 0x6b, 0x23,
- 0xe7, 0x38, 0x90, 0xb1, 0xdf, 0xb8, 0xc4, 0xad, 0xb3, 0x72, 0x4f, 0x33, 0x20, 0x19, 0xd0, 0xc9,
- 0xc5, 0xc5, 0x45, 0x5a, 0xc6, 0xd4, 0xc0, 0x0d, 0x28, 0x05, 0x6a, 0x83, 0x38, 0xc0, 0xce, 0xb3,
- 0xbe, 0xbe, 0x7e, 0x3f, 0x2c, 0x2c, 0xec, 0xb3, 0x1d, 0xd0, 0x09, 0xb5, 0xf0, 0x6d, 0xce, 0xe0,
- 0x0b, 0x2d, 0xa7, 0x1e, 0xc7, 0x6a, 0xa2, 0xcd, 0x25, 0xed, 0x45, 0x8b, 0x17, 0x34, 0xe7, 0xad,
- 0xdc, 0x3a, 0x13, 0xea, 0x36, 0x0a, 0x48, 0x2c, 0xe4, 0x03, 0x0f, 0xce, 0x28, 0x95, 0xca, 0x9b,
- 0x38, 0xf1, 0xb7, 0x3a, 0x9d, 0x2e, 0xce, 0x60, 0x30, 0xc8, 0x3b, 0x3b, 0x3b, 0x2b, 0xa1, 0x5a,
- 0xd8, 0xb3, 0x6c, 0xbb, 0x63, 0xb7, 0xcf, 0xa2, 0xd4, 0xf5, 0x62, 0xb1, 0x58, 0xb0, 0x5b, 0x0c,
- 0x48, 0xb0, 0xb7, 0x5a, 0x54, 0x73, 0x50, 0x31, 0x78, 0x2b, 0x45, 0x6b, 0x4e, 0x8c, 0x93, 0x0a,
- 0xef, 0xdd, 0x80, 0x18, 0xec, 0x71, 0x42, 0x19, 0x0b, 0xa8, 0xe2, 0xe2, 0xe2, 0xdc, 0x91, 0x2b,
- 0x8f, 0xf8, 0xf8, 0xf8, 0x2b, 0x63, 0x63, 0x63, 0x1a, 0x87, 0x33, 0xd6, 0x92, 0x92, 0x12, 0x43,
- 0x48, 0x48, 0x88, 0xdf, 0x13, 0xe5, 0xcd, 0x48, 0x18, 0x6f, 0x6f, 0xa5, 0xb0, 0x71, 0x3f, 0xc4,
- 0x4b, 0xe1, 0x69, 0x71, 0x3e, 0xeb, 0xac, 0x05, 0x40, 0x02, 0xbd, 0x08, 0xf1, 0xf7, 0x57, 0x5c,
- 0x5e, 0x5e, 0x1e, 0x53, 0x5f, 0x5f, 0x5f, 0xc2, 0x15, 0x02, 0x3c, 0xd4, 0x47, 0x44, 0x44, 0xbc,
- 0xf6, 0xd4, 0x3e, 0xa2, 0x5e, 0x41, 0x6e, 0xee, 0xc1, 0xae, 0xd7, 0x99, 0x2f, 0x05, 0x0d, 0x9e,
- 0x61, 0x02, 0x93, 0xeb, 0xd5, 0x67, 0x5b, 0x78, 0x7c, 0xde, 0x0f, 0x58, 0xbf, 0x09, 0xf9, 0xd3,
- 0xc6, 0xdd, 0xd3, 0x3b, 0x2f, 0x55, 0x56, 0x56, 0xe6, 0x14, 0x16, 0x16, 0x86, 0x63, 0xfc, 0x88,
- 0x51, 0xda, 0x0f, 0x29, 0x04, 0x5e, 0xe9, 0x00, 0xf9, 0xf8, 0xef, 0x27, 0xc3, 0x9f, 0x30, 0x17,
- 0x88, 0x75, 0x9c, 0xfe, 0x15, 0xe8, 0x79, 0x47, 0xb3, 0xf2, 0xa3, 0xa3, 0xa3, 0x59, 0xee, 0x5d,
- 0x00, 0x22, 0x47, 0x47, 0x47, 0x49, 0x47, 0x47, 0xc7, 0x7d, 0x4c, 0x82, 0x6b, 0xb3, 0xb3, 0xb3,
- 0x77, 0xd0, 0xb4, 0x9d, 0x52, 0xa9, 0xf4, 0xf6, 0xa1, 0x66, 0x1d, 0x9e, 0x67, 0xf6, 0x8e, 0x1e,
- 0xcc, 0xb2, 0xdb, 0x7a, 0xbd, 0x7e, 0xb6, 0xb8, 0xb8, 0x38, 0xa9, 0xa0, 0xa0, 0x20, 0xb4, 0xbd,
- 0xbd, 0xfd, 0xc7, 0xa9, 0xa9, 0x29, 0xea, 0xc1, 0xef, 0x6a, 0xb5, 0x5a, 0x9e, 0x9b, 0x9b, 0x5b,
- 0xdb, 0xd5, 0xd5, 0x65, 0x36, 0x1a, 0x8d, 0xa6, 0xd4, 0xd4, 0x54, 0xbf, 0x23, 0x0f, 0xd5, 0xf2,
- 0xf2, 0x72, 0x05, 0x7a, 0x87, 0x0c, 0x0f, 0x0f, 0x93, 0xf1, 0xf1, 0x71, 0x32, 0x3d, 0x3d, 0x4d,
- 0x50, 0xe6, 0xb4, 0x84, 0xb7, 0x65, 0xb1, 0x58, 0xe8, 0x44, 0x20, 0x78, 0xe7, 0x67, 0x84, 0xd5,
- 0xff, 0xc8, 0x20, 0x8c, 0x14, 0xd7, 0xb6, 0xb6, 0xb6, 0x47, 0x78, 0xc8, 0xdc, 0xdc, 0x1c, 0x41,
- 0x89, 0x13, 0x34, 0x29, 0x59, 0x5b, 0x5b, 0x23, 0x68, 0x60, 0x62, 0x36, 0x9b, 0x09, 0x9a, 0x97,
- 0x20, 0xa4, 0xd2, 0xe3, 0x5c, 0x13, 0x4e, 0x59, 0x59, 0x59, 0xc1, 0x08, 0x95, 0x8d, 0xf3, 0xa2,
- 0xaf, 0xaf, 0xaf, 0xa7, 0xa2, 0xa2, 0xe2, 0x0b, 0xc0, 0x15, 0xf0, 0xd0, 0x3c, 0x33, 0x33, 0x43,
- 0x68, 0x28, 0x9b, 0x9b, 0x9b, 0x4d, 0xc8, 0xd9, 0x25, 0x1c, 0xcc, 0xe3, 0x50, 0x20, 0xf4, 0xc3,
- 0x37, 0x3d, 0x3d, 0x3d, 0x93, 0x30, 0xb6, 0x41, 0xbd, 0xb0, 0x5a, 0xad, 0x34, 0x2f, 0x33, 0x7b,
- 0x0b, 0x03, 0x4d, 0x9b, 0x4f, 0x3d, 0x1d, 0x1a, 0x1a, 0x22, 0x03, 0x03, 0x03, 0x04, 0x79, 0xb2,
- 0xe3, 0x10, 0x23, 0x87, 0x02, 0x95, 0x95, 0x95, 0x7d, 0x8f, 0x01, 0xb9, 0x48, 0x43, 0x43, 0x3d,
- 0x59, 0x5d, 0x5d, 0xa5, 0x79, 0xfa, 0x75, 0xef, 0x89, 0xd1, 0x43, 0x99, 0x34, 0x77, 0x28, 0x06,
- 0x02, 0x0f, 0x6d, 0x98, 0x18, 0xbf, 0x14, 0x15, 0x15, 0x19, 0x0f, 0x1d, 0x3a, 0x5c, 0xd1, 0x0c,
- 0x3c, 0x8b, 0xa2, 0x61, 0xa3, 0x40, 0x9a, 0xa3, 0xd6, 0xd6, 0xd6, 0xbb, 0xf9, 0xf9, 0xf9, 0x41,
- 0x75, 0x75, 0x75, 0x09, 0xbd, 0xbd, 0xbd, 0xbf, 0xa1, 0xcc, 0x49, 0x53, 0x53, 0x13, 0xa9, 0xaa,
- 0xaa, 0x1a, 0xc0, 0x78, 0xe2, 0x1f, 0xb9, 0x18, 0x30, 0x6e, 0x5c, 0x10, 0xc2, 0x47, 0x5c, 0x2e,
- 0x10, 0xbe, 0xed, 0x50, 0xd1, 0x4a, 0x04, 0x94, 0x68, 0x34, 0x1a, 0xd2, 0xd8, 0xd8, 0x48, 0x14,
- 0x0a, 0x85, 0xf2, 0x58, 0xff, 0x19, 0x70, 0xd7, 0x44, 0x23, 0x0f, 0xb6, 0xc9, 0xc9, 0x49, 0x32,
- 0x32, 0x32, 0x42, 0x4c, 0x26, 0x13, 0xe1, 0xbc, 0x68, 0x68, 0x68, 0x20, 0xc8, 0x13, 0x41, 0x9f,
- 0xd1, 0xdf, 0xab, 0xb8, 0xab, 0x3e, 0x3c, 0x32, 0x08, 0x71, 0xaf, 0x80, 0xf1, 0x35, 0x24, 0x59,
- 0x85, 0x90, 0x15, 0xa8, 0x54, 0xaa, 0x9f, 0x28, 0x04, 0x5e, 0xd8, 0xd1, 0xc4, 0xed, 0x91, 0x91,
- 0x91, 0x61, 0xc8, 0x67, 0x23, 0x9a, 0x77, 0x3c, 0x3d, 0x3d, 0xfd, 0xf5, 0x23, 0x83, 0xe8, 0x35,
- 0x1e, 0x14, 0x14, 0xf4, 0x2e, 0x3e, 0x2f, 0x40, 0x6f, 0x06, 0x06, 0x06, 0xca, 0xb4, 0x5a, 0x2d,
- 0xc1, 0xbc, 0xb3, 0x30, 0x0c, 0xf3, 0x01, 0xd6, 0xde, 0x80, 0x5e, 0x0e, 0x08, 0x08, 0x38, 0x4b,
- 0x6f, 0xe1, 0xe3, 0x80, 0xf8, 0xd0, 0x09, 0xe8, 0x34, 0x74, 0xde, 0xdf, 0xdf, 0xff, 0xb2, 0x5c,
- 0x2e, 0xef, 0x4e, 0x49, 0x49, 0x51, 0xe3, 0xf7, 0x45, 0xe8, 0x9c, 0x63, 0x2e, 0x7a, 0x3c, 0x6d,
- 0xff, 0x1f, 0xf7, 0x45, 0xe5, 0x1b, 0x78, 0x1b, 0xf3, 0xdd, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45,
- 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82,
-};
-
-const BITMAP_OPAQUE export_options_pad_xpm[1] = {{ png, sizeof( png ), "export_options_pad_xpm" }};
-
-//EOF
diff --git a/bitmaps_png/cpp_26/global_options_pad.cpp b/bitmaps_png/cpp_26/global_options_pad.cpp
deleted file mode 100644
index 19c6b2525..000000000
--- a/bitmaps_png/cpp_26/global_options_pad.cpp
+++ /dev/null
@@ -1,86 +0,0 @@
-
-/* Do not modify this file, it was automatically generated by the
- * PNG2cpp CMake script, using a *.png file as input.
- */
-
-#include <bitmaps.h>
-
-static const unsigned char png[] = {
- 0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d, 0x49, 0x48, 0x44, 0x52,
- 0x00, 0x00, 0x00, 0x1a, 0x00, 0x00, 0x00, 0x1a, 0x08, 0x06, 0x00, 0x00, 0x00, 0xa9, 0x4a, 0x4c,
- 0xce, 0x00, 0x00, 0x04, 0x49, 0x49, 0x44, 0x41, 0x54, 0x48, 0xc7, 0xbd, 0x96, 0x6d, 0x4c, 0x5b,
- 0x65, 0x14, 0xc7, 0x5b, 0x23, 0xd6, 0x0d, 0xca, 0x6d, 0x0b, 0x05, 0xc5, 0x99, 0xc5, 0x97, 0x64,
- 0x7e, 0x5c, 0xa2, 0xc6, 0xa9, 0xd1, 0x8f, 0xc6, 0x38, 0xa7, 0xd3, 0x4c, 0x3f, 0x2c, 0x88, 0x31,
- 0x7e, 0x51, 0x23, 0xfa, 0x65, 0x33, 0x0e, 0xe9, 0x2b, 0x2f, 0x83, 0xb8, 0xb0, 0x4e, 0xe6, 0x64,
- 0x20, 0x21, 0x6c, 0x94, 0x19, 0x90, 0x0d, 0x14, 0x18, 0xba, 0xd2, 0x17, 0x32, 0x9c, 0x0e, 0xca,
- 0xba, 0x8e, 0x0e, 0xc7, 0x7b, 0x5b, 0xa4, 0x2d, 0xa5, 0x2d, 0xd0, 0x64, 0xeb, 0x8b, 0xf7, 0x1e,
- 0xcf, 0xb9, 0x50, 0xc4, 0xb9, 0x32, 0x4a, 0x8c, 0x37, 0xf9, 0xf7, 0xa6, 0xf7, 0x3e, 0xcf, 0xf9,
- 0x3d, 0xe7, 0x9c, 0xff, 0xf3, 0xe4, 0x0a, 0x00, 0x40, 0xf0, 0x7f, 0xe8, 0x5f, 0x0f, 0x72, 0x2d,
- 0xcc, 0x23, 0x72, 0x93, 0xac, 0x44, 0x6e, 0x90, 0x76, 0xca, 0x2f, 0x48, 0xcd, 0xd9, 0x9d, 0xcc,
- 0x09, 0x59, 0x3d, 0xf3, 0x92, 0x40, 0x20, 0xd8, 0x82, 0xba, 0xe7, 0x3f, 0x01, 0xc9, 0x8d, 0xd2,
- 0xa2, 0x1c, 0x93, 0xf4, 0x26, 0x0a, 0x6e, 0x13, 0x97, 0xad, 0x67, 0xba, 0x45, 0x4f, 0x89, 0x76,
- 0xac, 0x00, 0x85, 0x9b, 0x06, 0xc9, 0x7b, 0x25, 0x85, 0x77, 0x00, 0xfc, 0x43, 0xd2, 0x9a, 0xcc,
- 0x21, 0x84, 0x3c, 0x8b, 0x12, 0xa7, 0x0a, 0xe3, 0x7f, 0xf2, 0x2c, 0xb2, 0x87, 0x31, 0x50, 0x24,
- 0x11, 0xf0, 0x41, 0x53, 0x36, 0x57, 0xd0, 0x99, 0x1f, 0x3c, 0x78, 0xe1, 0x40, 0x68, 0xfb, 0xcf,
- 0x79, 0xf1, 0xb5, 0xb0, 0xad, 0x6f, 0x8b, 0x5a, 0x11, 0xf2, 0x0c, 0x65, 0x96, 0x32, 0x48, 0x6e,
- 0x90, 0xbc, 0xbb, 0x1a, 0xcc, 0x28, 0xe5, 0xce, 0x5f, 0xea, 0x9e, 0x87, 0x95, 0xcb, 0x3d, 0xeb,
- 0xbe, 0xf9, 0xc0, 0x8f, 0x59, 0xab, 0x8b, 0x60, 0xb4, 0x19, 0xe3, 0x08, 0x39, 0x80, 0xda, 0x96,
- 0x4a, 0x56, 0xcb, 0x20, 0x93, 0xec, 0x68, 0x22, 0xd0, 0xf6, 0xb6, 0x87, 0xc2, 0x2c, 0xcb, 0x72,
- 0xb0, 0xe6, 0x7a, 0xa3, 0xf9, 0x75, 0x7f, 0xe2, 0xbd, 0xac, 0x21, 0x33, 0x84, 0x80, 0x6a, 0xd4,
- 0x4e, 0x54, 0x5a, 0x8a, 0x19, 0xc9, 0xde, 0x5f, 0xcd, 0xc8, 0x20, 0xe5, 0xcc, 0x03, 0xa6, 0x60,
- 0x02, 0xe2, 0xf3, 0xfb, 0x22, 0x79, 0x1d, 0x39, 0xb7, 0xfe, 0xce, 0x28, 0xdd, 0x85, 0x80, 0x5a,
- 0xd4, 0x0b, 0xa9, 0x94, 0x6f, 0xd9, 0xd2, 0x06, 0xe6, 0x51, 0x0c, 0xb2, 0xda, 0x8b, 0x6d, 0x86,
- 0x5c, 0xf6, 0x93, 0xae, 0x8f, 0x83, 0xe5, 0xc6, 0xd2, 0xe0, 0x8e, 0x9e, 0xc7, 0xa2, 0x6b, 0x7b,
- 0xb4, 0xe5, 0x35, 0x91, 0x15, 0x01, 0x5f, 0xbd, 0xba, 0xe7, 0x95, 0x82, 0x62, 0x65, 0x51, 0xbb,
- 0x5a, 0xa3, 0xe8, 0x57, 0x6b, 0x15, 0x37, 0x54, 0xea, 0xe2, 0x91, 0x62, 0xe5, 0xa1, 0x27, 0xd6,
- 0x05, 0x51, 0xad, 0xb3, 0x3b, 0x24, 0xda, 0xbb, 0xb9, 0x4e, 0xa2, 0x13, 0x7b, 0x85, 0x42, 0x61,
- 0xcb, 0xbe, 0xb7, 0xde, 0xec, 0x52, 0xaa, 0xbf, 0x60, 0xdb, 0xce, 0xb5, 0xb2, 0x7d, 0x7d, 0x16,
- 0xb0, 0x5a, 0x07, 0x40, 0x7f, 0xa6, 0x89, 0x55, 0xa8, 0x8a, 0xfc, 0x08, 0x63, 0xd6, 0xb5, 0xb7,
- 0xe0, 0x49, 0x41, 0x5a, 0x76, 0x2b, 0x53, 0x9b, 0xd3, 0x2b, 0x65, 0xef, 0x68, 0x6d, 0x9d, 0xd8,
- 0x23, 0x94, 0x08, 0xdb, 0xf3, 0xdf, 0xd9, 0x3f, 0x50, 0x5e, 0x51, 0x12, 0xbf, 0x6a, 0xb7, 0x81,
- 0xd3, 0xe9, 0x84, 0xe9, 0xe9, 0x69, 0x18, 0x1a, 0xb2, 0x82, 0xb6, 0x54, 0xc5, 0x22, 0xe4, 0xbd,
- 0x0d, 0x6d, 0x58, 0xbc, 0x44, 0xe2, 0xc2, 0xad, 0x7b, 0x64, 0xc7, 0xc5, 0xbd, 0x59, 0x8d, 0x99,
- 0x7f, 0x64, 0xe9, 0x99, 0x80, 0xa4, 0x42, 0x3c, 0x79, 0xff, 0xcb, 0x22, 0x23, 0xbe, 0x3b, 0xc9,
- 0x48, 0x98, 0x43, 0xb8, 0xea, 0xa8, 0xfd, 0x9a, 0x1d, 0x26, 0x27, 0x27, 0x61, 0x6a, 0x6a, 0x0a,
- 0x06, 0x07, 0x07, 0x40, 0xa3, 0x55, 0x12, 0xa4, 0x60, 0xc3, 0x27, 0x03, 0x95, 0x90, 0x9c, 0x84,
- 0x92, 0xaf, 0xb8, 0x6a, 0x37, 0x6a, 0x3f, 0x6a, 0x2f, 0x6a, 0x57, 0xe1, 0xa7, 0x1f, 0x29, 0x8e,
- 0x55, 0x1f, 0x8d, 0xce, 0xcc, 0xcc, 0xc0, 0xd8, 0xd8, 0x18, 0x8c, 0x8e, 0x8e, 0x02, 0x96, 0x90,
- 0x43, 0x48, 0x7e, 0xca, 0x67, 0xdd, 0x1a, 0xe0, 0x7d, 0xa8, 0x74, 0x14, 0x83, 0xca, 0xa0, 0x6c,
- 0x55, 0x9a, 0xe2, 0x7e, 0xb3, 0xc5, 0x04, 0x2e, 0x97, 0x8b, 0xcf, 0x66, 0x78, 0x78, 0x98, 0x40,
- 0xe1, 0x64, 0xc1, 0x71, 0x01, 0x2f, 0xa2, 0xe4, 0x49, 0x41, 0xc9, 0x84, 0x41, 0xcf, 0x59, 0xfa,
- 0xcc, 0xe0, 0xf5, 0x7a, 0xc1, 0xe3, 0xf1, 0x80, 0xfd, 0xda, 0x55, 0x50, 0x69, 0x14, 0x9e, 0x24,
- 0x90, 0xdd, 0xb8, 0xb0, 0x18, 0x6a, 0x98, 0x0c, 0x92, 0x12, 0x08, 0x27, 0xe8, 0xce, 0xf7, 0x74,
- 0xc5, 0x43, 0xa1, 0x10, 0x04, 0x83, 0x41, 0x34, 0xc2, 0x14, 0x94, 0x96, 0x6b, 0xa8, 0x3f, 0x07,
- 0x6f, 0x1b, 0xb7, 0x17, 0xcd, 0x11, 0xb7, 0x0e, 0x0d, 0x42, 0x95, 0xee, 0x08, 0x6f, 0x92, 0x54,
- 0x41, 0x9a, 0xef, 0x5a, 0x9a, 0xa3, 0xb3, 0xb3, 0xb3, 0x7c, 0xf9, 0xa8, 0x57, 0x8e, 0xeb, 0x0e,
- 0x40, 0x17, 0x92, 0xb5, 0xab, 0xf1, 0xfd, 0x67, 0xa8, 0x13, 0xe4, 0xc0, 0xdf, 0x2e, 0xff, 0xca,
- 0xb9, 0xdc, 0x2e, 0xa8, 0xfc, 0xf2, 0x30, 0xe0, 0xb3, 0x5d, 0xa9, 0x40, 0x9e, 0xc6, 0x8d, 0x19,
- 0xf9, 0xe5, 0x52, 0x3f, 0x47, 0xfd, 0x21, 0xd7, 0x91, 0xc8, 0xde, 0xd7, 0x47, 0x1c, 0x50, 0x5b,
- 0x57, 0x13, 0x6b, 0x6a, 0x3e, 0x1d, 0xe9, 0xec, 0xfa, 0x21, 0x6e, 0xb3, 0x5d, 0xe1, 0x17, 0x32,
- 0x3e, 0x31, 0x4e, 0x3d, 0x24, 0x90, 0x78, 0xa3, 0x90, 0xc7, 0x11, 0x12, 0x32, 0x99, 0x8d, 0x2c,
- 0xf5, 0x87, 0x82, 0x50, 0x56, 0x24, 0xea, 0x15, 0x3d, 0x9b, 0x9f, 0x9f, 0x87, 0xb9, 0xb9, 0x39,
- 0x5e, 0x3e, 0x9f, 0x8f, 0xd7, 0xc5, 0xfe, 0x8b, 0x1c, 0xf6, 0x68, 0x7a, 0x43, 0x66, 0x40, 0x48,
- 0x2e, 0x0e, 0x76, 0xf7, 0xfc, 0xd4, 0xcd, 0xf7, 0xc6, 0xe1, 0x70, 0x80, 0xcd, 0x66, 0x83, 0x89,
- 0x89, 0x09, 0x58, 0x58, 0x58, 0xe0, 0x45, 0xcf, 0x49, 0x89, 0xff, 0x8b, 0x8b, 0x8b, 0xf0, 0xfb,
- 0x8d, 0x11, 0x28, 0x3b, 0xac, 0xfd, 0x13, 0xe7, 0x3f, 0x77, 0x57, 0x10, 0x0e, 0xca, 0x40, 0x88,
- 0xbd, 0xbd, 0xe3, 0x6c, 0x3c, 0x1c, 0x0e, 0xf3, 0x65, 0xa2, 0xd5, 0xbb, 0xdd, 0x6e, 0xfe, 0x4e,
- 0xab, 0xa7, 0x86, 0x53, 0xe0, 0x68, 0x34, 0xca, 0x2b, 0x18, 0x0a, 0xc2, 0x15, 0x2c, 0x5d, 0x49,
- 0x99, 0x9a, 0x20, 0x1f, 0xae, 0xbb, 0x8f, 0x56, 0x20, 0x69, 0x08, 0x31, 0xea, 0xcf, 0x9c, 0x8e,
- 0x2d, 0x2d, 0x2d, 0xf1, 0x25, 0x4a, 0x94, 0x86, 0x40, 0x81, 0x60, 0x00, 0x8e, 0x55, 0x57, 0xc5,
- 0xb0, 0x07, 0x21, 0x4d, 0x89, 0x92, 0x6b, 0x3c, 0xd5, 0x10, 0x69, 0x68, 0xac, 0xbf, 0x85, 0x46,
- 0x00, 0x2c, 0xf3, 0xc8, 0x5a, 0x48, 0x52, 0x10, 0x0e, 0x12, 0x62, 0x00, 0x7d, 0xdd, 0xb7, 0x35,
- 0xb1, 0x40, 0x20, 0xc0, 0xd7, 0x9b, 0x32, 0xf0, 0xfb, 0xfd, 0x7c, 0x7f, 0xa8, 0x4c, 0xdf, 0x9c,
- 0x3c, 0x4e, 0x90, 0x0e, 0x1c, 0x7b, 0x2f, 0xea, 0x79, 0xd4, 0x07, 0xa8, 0xcf, 0x51, 0x3b, 0x37,
- 0x7c, 0x32, 0xa0, 0x55, 0x2b, 0xab, 0xbf, 0xd6, 0xc5, 0x3d, 0xde, 0xe5, 0x2c, 0x28, 0x1b, 0x6a,
- 0x36, 0x1d, 0xa2, 0x21, 0x2c, 0x4d, 0x7d, 0x43, 0x5d, 0x94, 0xb2, 0xc5, 0xa0, 0xa2, 0x4d, 0x7f,
- 0x6e, 0xe1, 0xe4, 0xc2, 0x23, 0x55, 0x95, 0xac, 0xd3, 0xe5, 0xe4, 0x83, 0x13, 0x84, 0x36, 0x67,
- 0x02, 0xd2, 0xd4, 0x7c, 0x8a, 0x20, 0x97, 0x71, 0x5c, 0xfa, 0xa6, 0x3f, 0xb7, 0x70, 0xf2, 0xbe,
- 0x8a, 0xca, 0x32, 0x76, 0x6c, 0x6c, 0x14, 0xa8, 0x64, 0x64, 0x5f, 0xba, 0x53, 0xb9, 0xa8, 0xc9,
- 0xdf, 0xb7, 0xb5, 0xd0, 0x91, 0xe2, 0xc0, 0x71, 0x92, 0x54, 0x3f, 0xb7, 0xfe, 0x02, 0xac, 0x2e,
- 0xf9, 0xc7, 0x3b, 0xe6, 0x49, 0x55, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42,
- 0x60, 0x82,
-};
-
-const BITMAP_OPAQUE global_options_pad_xpm[1] = {{ png, sizeof( png ), "global_options_pad_xpm" }};
-
-//EOF
diff --git a/bitmaps_png/cpp_26/options_new_pad.cpp b/bitmaps_png/cpp_26/options_new_pad.cpp
deleted file mode 100644
index 8b8e953d7..000000000
--- a/bitmaps_png/cpp_26/options_new_pad.cpp
+++ /dev/null
@@ -1,99 +0,0 @@
-
-/* Do not modify this file, it was automatically generated by the
- * PNG2cpp CMake script, using a *.png file as input.
- */
-
-#include <bitmaps.h>
-
-static const unsigned char png[] = {
- 0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d, 0x49, 0x48, 0x44, 0x52,
- 0x00, 0x00, 0x00, 0x1a, 0x00, 0x00, 0x00, 0x1a, 0x08, 0x06, 0x00, 0x00, 0x00, 0xa9, 0x4a, 0x4c,
- 0xce, 0x00, 0x00, 0x05, 0x23, 0x49, 0x44, 0x41, 0x54, 0x48, 0xc7, 0xa5, 0x96, 0x7f, 0x4c, 0x95,
- 0x55, 0x1c, 0xc6, 0x1f, 0x7f, 0x90, 0xc3, 0x42, 0x18, 0x02, 0x82, 0x70, 0x45, 0x19, 0x2a, 0x91,
- 0x48, 0xea, 0x88, 0x5a, 0x32, 0x28, 0x24, 0xe6, 0x44, 0xd2, 0x9c, 0xad, 0x26, 0x33, 0x5d, 0x2b,
- 0x24, 0xec, 0x22, 0x96, 0x48, 0x21, 0xa2, 0xd5, 0xdc, 0xfc, 0xc7, 0x45, 0x6c, 0x12, 0x6b, 0x6d,
- 0x39, 0x47, 0xab, 0xe5, 0xfc, 0x81, 0x3a, 0x70, 0x0a, 0x4e, 0x18, 0x0a, 0x5e, 0x26, 0x34, 0x20,
- 0x18, 0x98, 0x3f, 0x50, 0x52, 0x30, 0xb8, 0x17, 0xee, 0xbd, 0x5e, 0xf5, 0x02, 0xdf, 0x9e, 0xf3,
- 0xb2, 0x6b, 0x5c, 0xb9, 0x20, 0x19, 0xdb, 0xb3, 0xbd, 0xef, 0x39, 0xe7, 0x3d, 0x9f, 0xf3, 0x3d,
- 0xcf, 0x73, 0xce, 0x05, 0x22, 0x02, 0x57, 0xc2, 0x01, 0xb8, 0xe3, 0x2b, 0x44, 0x62, 0x0f, 0xbc,
- 0x00, 0x4c, 0x52, 0x1a, 0x6b, 0xac, 0x43, 0xc7, 0x8e, 0x61, 0x13, 0x75, 0x93, 0x9a, 0x36, 0x6a,
- 0x3e, 0xe7, 0x17, 0x4e, 0xb8, 0x1b, 0xe9, 0xd8, 0x8b, 0x56, 0xe4, 0x61, 0x10, 0x5f, 0xe2, 0x11,
- 0x3e, 0xc3, 0x10, 0xb6, 0xa2, 0x93, 0xfa, 0x0e, 0xaf, 0xc1, 0x9b, 0xc0, 0xc9, 0x63, 0x40, 0xa6,
- 0x9f, 0x3c, 0x89, 0xce, 0x8b, 0x17, 0x21, 0x7c, 0xce, 0x18, 0x13, 0x84, 0x6f, 0x10, 0xc8, 0xd5,
- 0x57, 0x13, 0x60, 0x26, 0xcc, 0xca, 0x67, 0x79, 0xac, 0x1c, 0x3c, 0x44, 0x2a, 0x2c, 0x78, 0x0f,
- 0x7f, 0x11, 0xf6, 0x3e, 0x61, 0xd3, 0x9f, 0xac, 0x90, 0x93, 0xef, 0xaa, 0xaf, 0x87, 0xdc, 0xbd,
- 0x0b, 0x21, 0xb0, 0x9b, 0xef, 0x2f, 0x8c, 0x02, 0x71, 0xb2, 0xc9, 0x54, 0x2d, 0x21, 0x46, 0x27,
- 0xc0, 0x93, 0xca, 0x24, 0x2c, 0x05, 0xc6, 0xf0, 0xe5, 0xf8, 0x60, 0xff, 0x7e, 0xac, 0x3a, 0x7a,
- 0x14, 0x29, 0x0a, 0x40, 0xfd, 0x58, 0x5a, 0x0a, 0x6b, 0x4f, 0x0f, 0xe4, 0xc1, 0x03, 0x88, 0x02,
- 0xb2, 0xad, 0x9c, 0xda, 0x43, 0xa9, 0x31, 0xaf, 0x3a, 0x40, 0x59, 0xdc, 0xae, 0xfe, 0x71, 0x21,
- 0x0e, 0xa5, 0xc1, 0x1a, 0xb5, 0x0d, 0x0d, 0x47, 0x8e, 0xc0, 0x52, 0x59, 0x09, 0xb9, 0x76, 0x0d,
- 0x72, 0xef, 0x1e, 0xc4, 0x6c, 0x86, 0xd8, 0xed, 0xc3, 0x05, 0x58, 0x2c, 0x90, 0xde, 0x5e, 0xc8,
- 0xcd, 0x9b, 0x90, 0xc6, 0x46, 0xc8, 0x89, 0x13, 0x10, 0x07, 0xa8, 0x8b, 0xb2, 0x8e, 0x9a, 0x54,
- 0x79, 0x94, 0xf7, 0x44, 0xdb, 0x6e, 0x7a, 0x97, 0x82, 0xa1, 0x95, 0xeb, 0xa0, 0x27, 0xac, 0xeb,
- 0xca, 0x15, 0x88, 0xd1, 0x08, 0x19, 0x1c, 0x74, 0xb6, 0xed, 0xfe, 0x7d, 0xc8, 0xad, 0x5b, 0x90,
- 0x33, 0x67, 0xb4, 0xea, 0x0a, 0x15, 0xc4, 0xc7, 0xe5, 0xca, 0xdf, 0xa1, 0xf9, 0xc0, 0x2a, 0xc4,
- 0xd3, 0x9d, 0xdd, 0x0c, 0xc4, 0xc8, 0xbe, 0x0f, 0xe9, 0xd9, 0x52, 0xec, 0x58, 0xbe, 0x1c, 0x1b,
- 0x38, 0x49, 0xab, 0x82, 0xa9, 0x8a, 0x1c, 0x90, 0x81, 0x01, 0xc8, 0xed, 0xdb, 0x90, 0xd3, 0xa7,
- 0x31, 0xc4, 0xfe, 0x6c, 0xad, 0x18, 0x46, 0x38, 0x76, 0x54, 0x35, 0xd9, 0xf4, 0x42, 0x41, 0x80,
- 0xd7, 0xa9, 0xa9, 0x6c, 0xfb, 0xdd, 0xa9, 0xff, 0x13, 0xf6, 0xbf, 0x81, 0x22, 0xf6, 0xad, 0x3c,
- 0x7c, 0x18, 0xfa, 0xcb, 0x97, 0x87, 0x2b, 0x50, 0x72, 0x6c, 0x61, 0x67, 0xa7, 0x56, 0x89, 0xe1,
- 0x71, 0x18, 0xf0, 0x35, 0xe6, 0xf3, 0xe3, 0x01, 0xa7, 0x89, 0x72, 0x59, 0x41, 0x30, 0x36, 0xb0,
- 0xf7, 0x25, 0xac, 0xc7, 0x73, 0xa3, 0x16, 0xf2, 0x31, 0xdf, 0xa3, 0xb1, 0x4f, 0x81, 0x8a, 0x8b,
- 0xf1, 0x53, 0x4b, 0x0b, 0xa4, 0xab, 0x0b, 0xd2, 0xd4, 0x04, 0x51, 0x50, 0x05, 0x51, 0xbe, 0x95,
- 0x94, 0xc0, 0x42, 0xd8, 0xa4, 0x61, 0x90, 0x3a, 0x3b, 0x6a, 0xa2, 0x3c, 0xd8, 0x47, 0xf9, 0xf3,
- 0x29, 0x2e, 0xb3, 0xbd, 0x6f, 0xd4, 0xb6, 0x6e, 0xe4, 0x42, 0x74, 0xd8, 0xcc, 0xaf, 0xd7, 0x6d,
- 0xdf, 0x8e, 0xf6, 0x6f, 0xbf, 0x85, 0xd0, 0x2f, 0x55, 0x41, 0x25, 0xf5, 0x03, 0xcd, 0x7f, 0x58,
- 0x53, 0x03, 0x29, 0x2b, 0xd3, 0xda, 0x42, 0x46, 0xc6, 0xfb, 0x37, 0xec, 0x82, 0x69, 0x42, 0xa9,
- 0xdb, 0xce, 0x45, 0xbd, 0x8b, 0xdb, 0x84, 0x24, 0x78, 0x78, 0xb8, 0x1f, 0x48, 0x4c, 0x7c, 0x4b,
- 0x12, 0x12, 0xde, 0x1c, 0x8a, 0x8b, 0x9b, 0x9a, 0x3d, 0xe2, 0x4c, 0x05, 0x51, 0x05, 0x94, 0x8d,
- 0x7a, 0xfb, 0x5f, 0xd0, 0x3e, 0xf8, 0x6a, 0x67, 0x28, 0x1b, 0xf7, 0xc7, 0x83, 0xb8, 0xaf, 0x77,
- 0xb7, 0x7b, 0xbe, 0xec, 0x39, 0x84, 0x30, 0x7c, 0xae, 0x40, 0x3a, 0x5d, 0x40, 0xe5, 0xa1, 0x43,
- 0x87, 0xa4, 0xa0, 0xa0, 0x40, 0x02, 0x03, 0x03, 0xbf, 0x1f, 0xde, 0x22, 0xf8, 0xf2, 0xb9, 0xc2,
- 0xcf, 0xcf, 0x6f, 0x1d, 0x21, 0x01, 0xd4, 0x12, 0xe7, 0x9b, 0x61, 0x2f, 0xcd, 0xff, 0x02, 0x36,
- 0xed, 0x50, 0xba, 0x80, 0xb8, 0x25, 0xbb, 0x3d, 0x5c, 0x1a, 0xbd, 0x54, 0x32, 0x32, 0x32, 0x86,
- 0x82, 0x82, 0x82, 0xee, 0xe8, 0x74, 0xba, 0x8e, 0x35, 0x6b, 0xd6, 0x98, 0x1a, 0x1a, 0x1a, 0x78,
- 0x40, 0xeb, 0x25, 0x39, 0x39, 0xb9, 0x2f, 0x34, 0x34, 0xb4, 0x2d, 0x3c, 0x3c, 0xfc, 0x8e, 0x82,
- 0x47, 0x47, 0x47, 0x9b, 0x3c, 0x3c, 0x3c, 0xd6, 0xba, 0xbe, 0xeb, 0xf6, 0x20, 0x94, 0xa0, 0x3a,
- 0xc6, 0xd7, 0xce, 0x64, 0x99, 0xa1, 0x27, 0x54, 0x25, 0x6c, 0x33, 0xfd, 0x5a, 0x85, 0x7b, 0x0b,
- 0x5f, 0x5c, 0xd8, 0x7f, 0xfe, 0xfc, 0x79, 0x29, 0x2d, 0x2d, 0x95, 0x4b, 0x97, 0x2e, 0xd1, 0xf4,
- 0x4e, 0xe9, 0xe9, 0xe9, 0x11, 0xab, 0xd5, 0xca, 0x43, 0x6a, 0x91, 0xe6, 0xe6, 0x66, 0xb9, 0x7a,
- 0xf5, 0xaa, 0xd4, 0xd5, 0xd5, 0xc9, 0x82, 0x05, 0x0b, 0xd4, 0xf6, 0xfa, 0xbb, 0x04, 0x3d, 0xbe,
- 0x8e, 0xb6, 0x60, 0x09, 0x92, 0xe9, 0x5a, 0x12, 0x7e, 0x61, 0x8c, 0xf3, 0x99, 0xbd, 0xad, 0x98,
- 0x86, 0x24, 0x6f, 0x6f, 0xef, 0x5f, 0x73, 0x72, 0x72, 0xa4, 0xa3, 0xa3, 0x83, 0x29, 0xeb, 0x92,
- 0xbe, 0xbe, 0x3e, 0xad, 0x9a, 0xa6, 0xa6, 0x26, 0xed, 0xb9, 0xb7, 0xb7, 0x57, 0xba, 0xbb, 0xbb,
- 0x25, 0x3d, 0x3d, 0x7d, 0xc0, 0xcb, 0xcb, 0x6b, 0xdb, 0x98, 0xb7, 0xb7, 0x53, 0x07, 0x6f, 0x69,
- 0xed, 0x0c, 0x01, 0x9e, 0x94, 0x1f, 0xf5, 0xfc, 0xbc, 0x79, 0xf3, 0x9a, 0xab, 0xaa, 0xaa, 0xb4,
- 0x2a, 0xd4, 0xca, 0xe3, 0xe2, 0xe2, 0xfe, 0xe6, 0x36, 0x1a, 0xe6, 0xce, 0x9d, 0x5b, 0x1f, 0x1b,
- 0x1b, 0xdb, 0xdb, 0xda, 0xda, 0xaa, 0x55, 0x59, 0x56, 0x56, 0x26, 0x73, 0xe6, 0xcc, 0xf9, 0x83,
- 0xdf, 0xe8, 0x9e, 0x0a, 0x1a, 0x01, 0x8c, 0xa0, 0x1f, 0x6d, 0x61, 0x61, 0x61, 0x9d, 0x7a, 0xbd,
- 0xde, 0xaa, 0x20, 0x36, 0x9b, 0x4d, 0x32, 0x33, 0x33, 0x6d, 0x33, 0x66, 0xcc, 0xd8, 0xe8, 0x18,
- 0x17, 0x10, 0x10, 0xb0, 0x85, 0xfe, 0x3d, 0xba, 0x7e, 0xfd, 0xba, 0xb6, 0x85, 0x3b, 0x77, 0xee,
- 0xb4, 0xc7, 0xc4, 0xc4, 0xf4, 0xcc, 0x9a, 0x35, 0xeb, 0x2e, 0xe7, 0x08, 0x9d, 0x08, 0x28, 0x29,
- 0x2d, 0x2d, 0xcd, 0xde, 0xde, 0xde, 0xae, 0x6d, 0x8f, 0x82, 0x98, 0xcd, 0x66, 0x59, 0xbc, 0x78,
- 0x71, 0x17, 0xfb, 0x3c, 0x46, 0x8c, 0xf3, 0x8c, 0x8c, 0x8c, 0xec, 0x6e, 0x6c, 0x6c, 0x14, 0x83,
- 0xc1, 0xc0, 0x3b, 0xee, 0x8c, 0x14, 0x17, 0x17, 0x33, 0xfa, 0x09, 0x36, 0xf6, 0xc5, 0x4c, 0x04,
- 0x14, 0x16, 0x1c, 0x1c, 0x6c, 0x60, 0x45, 0x7f, 0xa6, 0xa6, 0xa6, 0x9a, 0x4d, 0x26, 0x13, 0x2f,
- 0x51, 0xa3, 0x64, 0x65, 0x65, 0x3d, 0xf2, 0xf1, 0xf1, 0xd9, 0xe1, 0x18, 0xc7, 0x38, 0xe7, 0xb2,
- 0x22, 0x7b, 0x4d, 0x4d, 0x8d, 0x9c, 0x3b, 0x77, 0x4e, 0x58, 0x8d, 0x91, 0x55, 0x1a, 0xa8, 0x9f,
- 0x39, 0x47, 0xe0, 0x53, 0x41, 0x23, 0x15, 0x12, 0x12, 0xd2, 0x52, 0x5b, 0x5b, 0xab, 0x19, 0xde,
- 0xd2, 0xd2, 0x22, 0xab, 0x57, 0xaf, 0xee, 0xa3, 0x6f, 0x6d, 0x54, 0x7b, 0x62, 0x62, 0x62, 0xbf,
- 0x02, 0x94, 0x97, 0x97, 0x4b, 0x61, 0x61, 0xa1, 0xcc, 0x9e, 0x3d, 0xbb, 0x7e, 0x42, 0x61, 0x70,
- 0x25, 0x7e, 0xbc, 0x3f, 0x37, 0x37, 0x57, 0x33, 0xfc, 0xc6, 0x8d, 0x1b, 0xa2, 0xcc, 0x57, 0xe1,
- 0x50, 0x80, 0x0b, 0x17, 0x2e, 0x68, 0xdb, 0x55, 0x52, 0x52, 0x22, 0x79, 0x79, 0x79, 0xc2, 0x0a,
- 0xab, 0x9e, 0x09, 0xc4, 0xbf, 0xf9, 0x11, 0x11, 0x11, 0xfc, 0xfd, 0xb9, 0x22, 0xa7, 0x4e, 0x9d,
- 0x92, 0xb3, 0x67, 0xcf, 0x6a, 0x5e, 0x54, 0x57, 0x57, 0x4b, 0x45, 0x45, 0x05, 0x7f, 0x12, 0x4e,
- 0x4b, 0x51, 0x51, 0x91, 0x0a, 0x81, 0x1c, 0x3f, 0x7e, 0x5c, 0x92, 0x92, 0x92, 0x2c, 0xbe, 0xbe,
- 0xbe, 0xfa, 0xff, 0x0c, 0xa2, 0x1f, 0x1f, 0xad, 0x58, 0xb1, 0xc2, 0xc4, 0xe4, 0x3d, 0xe0, 0x15,
- 0xd3, 0xc6, 0xf8, 0xb6, 0x31, 0xd2, 0x7d, 0x07, 0x0f, 0x1e, 0xd4, 0x4c, 0x8f, 0x8f, 0x8f, 0xef,
- 0x67, 0xc5, 0xad, 0xf4, 0xe4, 0xe8, 0xb2, 0x65, 0xcb, 0x7a, 0xa3, 0xa2, 0xa2, 0x8c, 0x33, 0x67,
- 0xce, 0x4c, 0x7b, 0xa6, 0xad, 0xf3, 0xf7, 0xf7, 0xdf, 0xca, 0xb8, 0xee, 0x73, 0xfc, 0x27, 0xe4,
- 0xe6, 0xe6, 0x96, 0x9a, 0x92, 0x92, 0x32, 0x98, 0x9f, 0x9f, 0x2f, 0xec, 0xab, 0x74, 0x8c, 0x73,
- 0x77, 0x77, 0x7f, 0x85, 0x90, 0x4d, 0xcf, 0xec, 0x91, 0xab, 0x44, 0x2e, 0x5a, 0xb4, 0xc8, 0xc2,
- 0x20, 0x0c, 0x71, 0x9b, 0x76, 0x8d, 0x3b, 0xf6, 0x7f, 0x82, 0xa6, 0x4e, 0x99, 0x32, 0x65, 0x3d,
- 0xb5, 0x96, 0xcf, 0x3e, 0xe3, 0x8d, 0xfd, 0x07, 0x09, 0x76, 0xaf, 0x10, 0x3b, 0xe5, 0x2f, 0x92,
- 0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82,
-};
-
-const BITMAP_OPAQUE options_new_pad_xpm[1] = {{ png, sizeof( png ), "options_new_pad_xpm" }};
-
-//EOF
diff --git a/bitmaps_png/cpp_26/push_pad_settings.cpp b/bitmaps_png/cpp_26/push_pad_settings.cpp
new file mode 100644
index 000000000..4a16e3f53
--- /dev/null
+++ b/bitmaps_png/cpp_26/push_pad_settings.cpp
@@ -0,0 +1,88 @@
+
+/* Do not modify this file, it was automatically generated by the
+ * PNG2cpp CMake script, using a *.png file as input.
+ */
+
+#include <bitmaps.h>
+
+static const unsigned char png[] = {
+ 0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d, 0x49, 0x48, 0x44, 0x52,
+ 0x00, 0x00, 0x00, 0x1a, 0x00, 0x00, 0x00, 0x1a, 0x08, 0x06, 0x00, 0x00, 0x00, 0xa9, 0x4a, 0x4c,
+ 0xce, 0x00, 0x00, 0x04, 0x70, 0x49, 0x44, 0x41, 0x54, 0x48, 0xc7, 0xc5, 0x96, 0x6b, 0x4c, 0x5b,
+ 0x65, 0x18, 0xc7, 0x41, 0xb6, 0x61, 0xb9, 0xf5, 0xb4, 0xb0, 0x12, 0xfd, 0xa0, 0x59, 0x34, 0x73,
+ 0x0e, 0x63, 0x8c, 0xc6, 0x44, 0x67, 0xa2, 0x6e, 0x7e, 0x32, 0x5e, 0xa3, 0xe9, 0x4c, 0x34, 0x9b,
+ 0xb7, 0x84, 0xe8, 0x22, 0x06, 0x95, 0x85, 0x5e, 0xce, 0x39, 0x9c, 0xb6, 0x0c, 0xc6, 0x65, 0x30,
+ 0x06, 0xd8, 0x31, 0x46, 0x1c, 0xe3, 0xb6, 0xb8, 0x0d, 0x65, 0xab, 0xdc, 0xb2, 0x02, 0x3a, 0x97,
+ 0x6d, 0x14, 0x70, 0x0b, 0xb4, 0xdc, 0x56, 0xa0, 0xdc, 0x29, 0x6d, 0x29, 0xb7, 0x42, 0x5b, 0x4e,
+ 0x5f, 0x9f, 0xf7, 0x84, 0x92, 0x6e, 0x41, 0x69, 0xeb, 0x07, 0xdf, 0xe4, 0x9f, 0xa6, 0x79, 0x2f,
+ 0xbf, 0xf3, 0x3c, 0xff, 0xff, 0x7b, 0xda, 0x90, 0x90, 0xff, 0x6b, 0x3c, 0xa2, 0x25, 0x1e, 0x17,
+ 0xb5, 0x08, 0xbf, 0xdf, 0xd9, 0x4c, 0x9c, 0x15, 0x35, 0x0a, 0xaa, 0x62, 0xeb, 0x08, 0x15, 0x5f,
+ 0x1d, 0x75, 0x00, 0xa6, 0x22, 0x41, 0xdb, 0x40, 0xa1, 0xff, 0x09, 0xf0, 0x64, 0x7d, 0x48, 0xb8,
+ 0xa8, 0x85, 0xc8, 0x13, 0xb5, 0x0a, 0x56, 0x41, 0xe8, 0x01, 0x79, 0xe2, 0x6a, 0x62, 0xae, 0xf3,
+ 0xde, 0xe3, 0xed, 0x5b, 0x07, 0x3e, 0x14, 0x34, 0x28, 0xbe, 0x55, 0xf0, 0xf3, 0x26, 0x80, 0xfb,
+ 0x14, 0x57, 0xcb, 0x9f, 0x0d, 0x8b, 0x0f, 0x7b, 0x1b, 0x96, 0x0b, 0x83, 0xaa, 0x2c, 0x5e, 0xcb,
+ 0x3f, 0xe0, 0x7b, 0xe0, 0xee, 0x86, 0x5d, 0xab, 0xca, 0x06, 0x85, 0x25, 0xb7, 0x29, 0xc7, 0xf2,
+ 0xe2, 0xd5, 0xe7, 0x97, 0x7c, 0xe7, 0xa2, 0x8f, 0x46, 0xfc, 0x09, 0x5b, 0xde, 0x00, 0x45, 0x05,
+ 0x0e, 0x6a, 0x13, 0x16, 0x78, 0x0f, 0x8a, 0xbf, 0x26, 0x64, 0xef, 0x8d, 0x0c, 0x2e, 0xa2, 0xf5,
+ 0xb1, 0xb8, 0xb8, 0xe8, 0x7e, 0x46, 0xb3, 0xc7, 0xe1, 0x9d, 0x17, 0x9e, 0x8b, 0xb1, 0xc2, 0x16,
+ 0x12, 0xb4, 0x2b, 0xe0, 0x16, 0xfa, 0xb6, 0x2d, 0x41, 0xf3, 0x94, 0x03, 0x3d, 0x30, 0x3e, 0xab,
+ 0x3b, 0x6c, 0xdb, 0x68, 0xdf, 0x2f, 0x84, 0x03, 0xb6, 0xfc, 0x08, 0x7a, 0x09, 0x14, 0x1e, 0x10,
+ 0x48, 0xd4, 0x22, 0x28, 0xda, 0x68, 0x0f, 0x54, 0x64, 0x1a, 0x37, 0x2d, 0x7b, 0x21, 0x0e, 0x87,
+ 0x63, 0xed, 0x39, 0x4d, 0xc2, 0xb2, 0x4f, 0x45, 0x76, 0xd8, 0x72, 0x16, 0xb4, 0x1f, 0x14, 0x11,
+ 0x10, 0x68, 0xa7, 0x56, 0xf0, 0xa6, 0xaf, 0x0f, 0x09, 0xbf, 0xed, 0x59, 0xc9, 0x6f, 0xce, 0x9b,
+ 0x2d, 0xd5, 0x96, 0x58, 0x5e, 0xad, 0x7b, 0x65, 0xe1, 0x3e, 0x8f, 0xbe, 0xe5, 0xf5, 0xc3, 0x96,
+ 0x62, 0xf1, 0x47, 0x1f, 0x1e, 0xa5, 0x18, 0x59, 0x1b, 0xad, 0x90, 0x2f, 0xc1, 0xe7, 0x52, 0x9a,
+ 0x82, 0xd2, 0x4b, 0x19, 0xe9, 0xee, 0xad, 0x58, 0xa1, 0xa2, 0x26, 0xa2, 0x79, 0xcb, 0xd4, 0x5d,
+ 0x22, 0x96, 0x77, 0xc4, 0xee, 0xb8, 0xf2, 0xf5, 0x91, 0x44, 0x83, 0x42, 0x45, 0xb3, 0xf5, 0xf5,
+ 0x1a, 0xf6, 0xee, 0xdd, 0x3b, 0x48, 0xaf, 0xef, 0x41, 0x55, 0x35, 0x95, 0x2c, 0xcd, 0xc8, 0x67,
+ 0x52, 0x53, 0x53, 0xf9, 0xff, 0x4a, 0x22, 0x92, 0x09, 0x22, 0xf6, 0x22, 0xff, 0xb2, 0x48, 0x2b,
+ 0x60, 0x37, 0x83, 0x08, 0xd4, 0xd1, 0xb3, 0xdb, 0x1e, 0x0b, 0x6b, 0x3c, 0xfc, 0xf9, 0xa1, 0xee,
+ 0xdc, 0xbc, 0x1c, 0x97, 0x71, 0xc8, 0x88, 0x4c, 0x26, 0x13, 0x1a, 0x19, 0x19, 0x41, 0x9d, 0x5d,
+ 0x1d, 0x48, 0x75, 0x8c, 0x61, 0x49, 0x5a, 0xfa, 0xa5, 0x3f, 0x1d, 0xc4, 0xf7, 0x22, 0x82, 0x77,
+ 0x88, 0xf7, 0x01, 0x5f, 0x15, 0xd9, 0x40, 0x14, 0x44, 0xdf, 0x13, 0x9c, 0x8a, 0x1e, 0x8b, 0x49,
+ 0x8d, 0x34, 0x3c, 0xbc, 0x7f, 0xbb, 0x16, 0xe6, 0xca, 0xf6, 0xee, 0x7d, 0x5a, 0x0d, 0xad, 0xf2,
+ 0xf4, 0x0f, 0xf4, 0x23, 0xa3, 0xd1, 0xc8, 0x41, 0x74, 0xba, 0x76, 0x84, 0xab, 0x93, 0xd3, 0xd2,
+ 0x4f, 0x03, 0xb1, 0x2b, 0x74, 0x3d, 0x49, 0x8f, 0x82, 0x5e, 0x06, 0x1d, 0x04, 0x7d, 0x01, 0xfa,
+ 0x18, 0xf4, 0x7a, 0xf2, 0x77, 0xdf, 0x94, 0x54, 0x56, 0x57, 0xb8, 0x46, 0x47, 0x47, 0xd1, 0xe0,
+ 0xe0, 0x20, 0x1a, 0x00, 0x20, 0xa3, 0x24, 0x3d, 0x72, 0x5a, 0xf2, 0x49, 0xb0, 0x2f, 0x0a, 0x2f,
+ 0x30, 0x06, 0x24, 0x00, 0xe1, 0xbe, 0xf3, 0x14, 0x4a, 0xba, 0xfd, 0xc6, 0x8d, 0xeb, 0x5c, 0xcb,
+ 0x86, 0x87, 0x87, 0x51, 0x0f, 0x78, 0x43, 0x33, 0xe4, 0xfc, 0x3f, 0x1d, 0x42, 0x51, 0xd2, 0xd7,
+ 0x18, 0xe6, 0x87, 0xb8, 0x80, 0xe9, 0xd0, 0xa2, 0xee, 0xae, 0xbf, 0xba, 0xd0, 0xd4, 0xd4, 0x14,
+ 0xa7, 0x9e, 0x9e, 0x6e, 0xa8, 0x88, 0x9a, 0xd8, 0x6c, 0xad, 0x8c, 0x96, 0xbd, 0x05, 0xd5, 0xba,
+ 0x68, 0x05, 0xd9, 0x23, 0x91, 0x48, 0x04, 0x01, 0x81, 0xd2, 0x94, 0x64, 0xeb, 0xed, 0xf6, 0x5b,
+ 0xc8, 0x66, 0xb3, 0x71, 0xc2, 0x1e, 0xa5, 0x67, 0x28, 0x58, 0x8a, 0x91, 0xa7, 0xf8, 0xae, 0x23,
+ 0x19, 0xe9, 0xfb, 0xca, 0xf4, 0x34, 0x77, 0x67, 0x57, 0xa7, 0xe7, 0xe4, 0xa9, 0x7c, 0x77, 0xc0,
+ 0xad, 0x25, 0x69, 0x49, 0xf6, 0xa5, 0xda, 0x8b, 0xae, 0x89, 0x89, 0x09, 0x34, 0x36, 0x36, 0x86,
+ 0xc6, 0xc7, 0xc7, 0x91, 0xde, 0xa0, 0x47, 0x19, 0xc7, 0x55, 0x2c, 0x95, 0x26, 0x2d, 0x84, 0xf9,
+ 0x54, 0x48, 0xde, 0x69, 0x48, 0xe0, 0x5a, 0xbb, 0xee, 0xb6, 0x07, 0xaf, 0x2b, 0x56, 0x17, 0xae,
+ 0x52, 0x94, 0xec, 0xa0, 0xdf, 0x10, 0x8a, 0x92, 0xbc, 0x00, 0x07, 0x38, 0x6e, 0xde, 0xba, 0xe9,
+ 0xc1, 0xfe, 0x0c, 0x0d, 0x0d, 0x71, 0xc2, 0x55, 0xf5, 0xf6, 0x1a, 0xd0, 0x99, 0x52, 0xb5, 0xab,
+ 0xa2, 0xb2, 0xdc, 0x79, 0x55, 0x73, 0x65, 0x0d, 0xdf, 0x2d, 0x1c, 0x18, 0xec, 0x65, 0x66, 0x56,
+ 0x3a, 0x92, 0x31, 0xb2, 0x67, 0xfd, 0xab, 0x84, 0x24, 0x9f, 0x50, 0xa8, 0x28, 0xdb, 0xef, 0x7f,
+ 0xb4, 0xb0, 0x93, 0x93, 0x93, 0x1c, 0x00, 0x7f, 0x7a, 0x35, 0x3d, 0x3d, 0x8d, 0x2c, 0x16, 0x0b,
+ 0x32, 0x9b, 0xcd, 0x68, 0x66, 0x66, 0x66, 0x43, 0xba, 0x0e, 0x9d, 0x07, 0x3c, 0x1a, 0xf7, 0x0b,
+ 0xc2, 0x30, 0x29, 0x22, 0x46, 0x49, 0x9b, 0x9a, 0x9a, 0x1b, 0xdd, 0xd8, 0x17, 0xbd, 0x5e, 0x8f,
+ 0x0c, 0x06, 0x03, 0x44, 0x7b, 0x00, 0xd9, 0xed, 0x76, 0x4e, 0x73, 0x73, 0x73, 0x9c, 0xbc, 0xdf,
+ 0xe7, 0xe7, 0xe7, 0xb9, 0xd6, 0x66, 0xe7, 0x66, 0xae, 0x81, 0x3f, 0x62, 0x3f, 0x20, 0x4c, 0x14,
+ 0xa4, 0xea, 0xce, 0xaf, 0x75, 0xb5, 0xee, 0x85, 0x85, 0x05, 0xae, 0x4d, 0xf8, 0x49, 0xb1, 0x37,
+ 0x38, 0x75, 0x66, 0xf3, 0x0c, 0x02, 0x2f, 0x20, 0x18, 0x56, 0xe4, 0x74, 0x3a, 0x39, 0xad, 0xac,
+ 0xac, 0xa0, 0xbe, 0xbe, 0x5e, 0x94, 0x7b, 0x22, 0xcb, 0x4d, 0x33, 0xb2, 0xa2, 0x2d, 0x21, 0x89,
+ 0x89, 0x89, 0xdb, 0x19, 0x05, 0x75, 0xad, 0xba, 0xa6, 0xc2, 0x85, 0x21, 0xf8, 0x60, 0x0c, 0xc1,
+ 0xed, 0xc1, 0x4f, 0x6b, 0xb5, 0x5a, 0x51, 0x7e, 0x41, 0x9e, 0x1b, 0xde, 0x14, 0xb6, 0xac, 0x9c,
+ 0x0c, 0x4f, 0xf9, 0xf9, 0x9f, 0x56, 0xab, 0x2f, 0x54, 0xad, 0x9e, 0xc8, 0xcf, 0x76, 0x43, 0xac,
+ 0x17, 0xe4, 0x94, 0x34, 0xd9, 0x9f, 0x5f, 0xe1, 0xd0, 0x34, 0x86, 0xac, 0x28, 0x2d, 0x2b, 0x71,
+ 0x59, 0xad, 0x96, 0x8d, 0x9e, 0x63, 0x1f, 0xb0, 0xc9, 0x18, 0x72, 0xfa, 0x4c, 0xb1, 0x0b, 0x1e,
+ 0xa4, 0x56, 0x2c, 0x16, 0x87, 0xc9, 0x19, 0xf9, 0x3e, 0x08, 0xcb, 0x11, 0x9c, 0x3a, 0x39, 0x2d,
+ 0x7f, 0x67, 0xcb, 0x17, 0xab, 0x77, 0x40, 0xc9, 0xc7, 0x0b, 0x8b, 0x4e, 0xae, 0x61, 0x93, 0x71,
+ 0x05, 0xb8, 0x1a, 0x7c, 0x38, 0x6e, 0x9d, 0xdd, 0x3e, 0x87, 0xce, 0x95, 0x97, 0x39, 0x01, 0xd2,
+ 0x96, 0x94, 0x94, 0x14, 0x1e, 0xf4, 0x9f, 0x14, 0x78, 0xb2, 0xaf, 0x72, 0xf3, 0xb2, 0x59, 0x93,
+ 0x69, 0x84, 0xab, 0x00, 0x43, 0x70, 0x08, 0x70, 0x25, 0xd8, 0xe8, 0x9a, 0x0b, 0x55, 0x4e, 0x48,
+ 0x52, 0x47, 0x4a, 0x4a, 0x4a, 0x64, 0xd0, 0x10, 0xb8, 0xd1, 0xef, 0x66, 0x66, 0x1d, 0x63, 0xfb,
+ 0xfb, 0xfb, 0x36, 0x20, 0xb8, 0x12, 0x0c, 0xc1, 0xb0, 0xcb, 0x70, 0x59, 0x21, 0x1c, 0x86, 0x80,
+ 0x5f, 0x29, 0x30, 0xfe, 0x06, 0xc4, 0xd8, 0x5b, 0x1b, 0x99, 0xad, 0x07, 0x38, 0x00, 0x00, 0x00,
+ 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82,
+};
+
+const BITMAP_OPAQUE push_pad_settings_xpm[1] = {{ png, sizeof( png ), "push_pad_settings_xpm" }};
+
+//EOF
diff --git a/pcbnew/tools/pad_tool.cpp b/pcbnew/tools/pad_tool.cpp
index b8c8df6a9..c96e25e75 100644
--- a/pcbnew/tools/pad_tool.cpp
+++ b/pcbnew/tools/pad_tool.cpp
@@ -49,8 +49,8 @@ public:
         SetIcon( pad_xpm );
         SetTitle( _( "Pads" ) );
 
-        Add( COMMON_ACTIONS::importPadSettings );
-        Add( COMMON_ACTIONS::exportPadSettings );
+        Add( COMMON_ACTIONS::copyPadSettings );
+        Add( COMMON_ACTIONS::applyPadSettings );
         Add( COMMON_ACTIONS::pushPadSettings );
     }
 
@@ -74,15 +74,15 @@ private:
                                 && SELECTION_CONDITIONS::OnlyType( PCB_PAD_T );
         auto emptySel = SELECTION_CONDITIONS::Count( 0 );
 
         // Import pads enabled when any pads selected (it applies to each one
         // individually)
         const bool canImport = ( anyPadSel )( selection );
-        Enable( getMenuId( COMMON_ACTIONS::importPadSettings ), canImport );
+        Enable( getMenuId( COMMON_ACTIONS::applyPadSettings ), canImport );
 
         // Export pads item enabled only when there is a single pad selected
         // (otherwise how would we know which one to export?)
         const bool canExport = ( singlePadSel )( selection );
-        Enable( getMenuId( COMMON_ACTIONS::exportPadSettings ), canExport );
+        Enable( getMenuId( COMMON_ACTIONS::copyPadSettings ), canExport );
 
         // Push pads available when nothing selected, or a single pad
         const bool canPush = ( singlePadSel || emptySel ) ( selection );
@@ -133,12 +133,12 @@ bool PAD_TOOL::Init()
 
 
 /**
- * Function doExportPadSettings
+ * Function doCopyPadSettings
  *
  * Export a given pad to the destination pad. Normally, the destination
  * would be a board reference settings master pad.
  */
-static void doExportPadSettings( const D_PAD& aSrc, D_PAD& aDest )
+static void doCopyPadSettings( const D_PAD& aSrc, D_PAD& aDest )
 {
     // Copy all settings. Some of them are not used, but they break anything
     aDest = aSrc;
@@ -151,13 +151,13 @@ static void doExportPadSettings( const D_PAD& aSrc, D_PAD& aDest )
 
 
 /**
- * Function doImportPadSettings
+ * Function doApplyPadSettings
  *
  * Import pad settings from a "reference" source to a destination.
  * Often, the reference source will be a board reference settings
  * master pad.
  */
-static void doImportPadSettings( const D_PAD& aSrc, D_PAD& aDest )
+static void doApplyPadSettings( const D_PAD& aSrc, D_PAD& aDest )
 {
     const auto& destParent = *aDest.GetParent();
 
@@ -202,7 +202,7 @@ static void doImportPadSettings( const D_PAD& aSrc, D_PAD& aDest )
 }
 
 
-int PAD_TOOL::importPadSettings( const TOOL_EVENT& aEvent )
+int PAD_TOOL::applyPadSettings( const TOOL_EVENT& aEvent )
 {
     auto& selTool = *m_toolMgr->GetTool<SELECTION_TOOL>();
     const auto& selection = selTool.GetSelection();
@@ -222,11 +222,11 @@ int PAD_TOOL::importPadSettings( const TOOL_EVENT& aEvent )
 
             auto& destPad = static_cast<D_PAD&>( *item );
 
-            doImportPadSettings( masterPad, destPad );
+            doApplyPadSettings( masterPad, destPad );
         }
     }
 
-    commit.Push( _( "Import Pad Settings" ) );
+    commit.Push( _( "Apply Pad Settings" ) );
 
     m_toolMgr->RunAction( COMMON_ACTIONS::editModifiedSelection, true );
     frame.Refresh();
@@ -235,7 +235,7 @@ int PAD_TOOL::importPadSettings( const TOOL_EVENT& aEvent )
 }
 
 
-int PAD_TOOL::exportPadSettings( const TOOL_EVENT& aEvent )
+int PAD_TOOL::copyPadSettings( const TOOL_EVENT& aEvent )
 {
     auto& selTool = *m_toolMgr->GetTool<SELECTION_TOOL>();
     const auto& selection = selTool.GetSelection();
@@ -244,7 +244,7 @@ int PAD_TOOL::exportPadSettings( const TOOL_EVENT& aEvent )
 
     D_PAD& masterPad = frame.GetDesignSettings().m_Pad_Master;
 
     // can only export from a single pad
     if( selection.Size() == 1 )
     {
         auto item = selection[0];
@@ -253,7 +253,7 @@ int PAD_TOOL::exportPadSettings( const TOOL_EVENT& aEvent )
         {
             const auto& selPad = static_cast<const D_PAD&>( *item );
 
-            doExportPadSettings( selPad, masterPad );
+            doCopyPadSettings( selPad, masterPad );
         }
     }
 
@@ -271,8 +271,8 @@ static void globalChangePadSettings( BOARD& board,
 {
     const MODULE* moduleRef = aSrcPad.GetParent();
 
-    // if there is no module, we can't make the comparisons to see which
-    // pads to aply the src pad settings to
+    // If there is no module, we can't make the comparisons to see which
+    // pads to apply the source pad settings to
     if( moduleRef == nullptr )
     {
         wxLogDebug( "globalChangePadSettings() Error: NULL module" );
@@ -308,8 +308,8 @@ static void globalChangePadSettings( BOARD& board,
 
             commit.Modify( pad );
 
-            // copy source pad settings to this pad
-            doImportPadSettings( aSrcPad, *pad );
+            // Apply source pad settings to this pad
+            doApplyPadSettings( aSrcPad, *pad );
         }
     }
 }
@@ -342,7 +342,7 @@ int PAD_TOOL::pushPadSettings( const TOOL_EVENT& aEvent )
     else
     {
         // multiple selected what to do?
         // maybe master->selection? same as import multiple?
     }
 
     // no valid selection, nothing to do
@@ -380,7 +380,7 @@ int PAD_TOOL::pushPadSettings( const TOOL_EVENT& aEvent )
                               DIALOG_GLOBAL_PADS_EDITION::m_Pad_Orient_Filter,
                               DIALOG_GLOBAL_PADS_EDITION::m_Pad_Layer_Filter );
 
-    commit.Push( _( "Import Pad Settings" ) );
+    commit.Push( _( "Apply Pad Settings" ) );
 
     m_toolMgr->RunAction( COMMON_ACTIONS::editModifiedSelection, true );
     frame.Refresh();
@@ -388,10 +388,9 @@ int PAD_TOOL::pushPadSettings( const TOOL_EVENT& aEvent )
     return 0;
 }
 
-
 void PAD_TOOL::SetTransitions()
 {
-    Go( &PAD_TOOL::importPadSettings, COMMON_ACTIONS::importPadSettings.MakeEvent() );
-    Go( &PAD_TOOL::exportPadSettings, COMMON_ACTIONS::exportPadSettings.MakeEvent() );
-    Go( &PAD_TOOL::pushPadSettings,   COMMON_ACTIONS::pushPadSettings.MakeEvent() );
+    Go( &PAD_TOOL::applyPadSettings, COMMON_ACTIONS::applyPadSettings.MakeEvent() );
+    Go( &PAD_TOOL::copyPadSettings,  COMMON_ACTIONS::copyPadSettings.MakeEvent() );
+    Go( &PAD_TOOL::pushPadSettings,  COMMON_ACTIONS::pushPadSettings.MakeEvent() );
 }
@@ -74,15 +74,15 @@ private:
         auto emptySel = SELECTION_CONDITIONS::Count( 0 );
 
-        // Import pads enabled when any pads selected (it applies to each one
+        // Apply pads enabled when any pads selected (it applies to each one
         // individually)
         const bool canImport = ( anyPadSel )( selection );
@@ -74,15 +74,15 @@ private:
 
-        // Export pads item enabled only when there is a single pad selected
-        // (otherwise how would we know which one to export?)
+        // Copy pads item enabled only when there is a single pad selected
+        // (otherwise how would we know which one to copy?)
         const bool canExport = ( singlePadSel )( selection );
@@ -133,12 +133,12 @@ bool PAD_TOOL::Init()
  *
- * Export a given pad to the destination pad. Normally, the destination
+ * Copy a given pad setting to the destination pad. Normally, the destination
  * would be a board reference settings master pad.
  */
@@ -151,13 +151,13 @@ static void doExportPadSettings( const D_PAD& aSrc, D_PAD& aDest )
  *
- * Import pad settings from a "reference" source to a destination.
+ * Apply pad settings from a "reference" source to a destination.
  * Often, the reference source will be a board reference settings
  * master pad.
@@ -244,7 +244,7 @@ int PAD_TOOL::exportPadSettings( const TOOL_EVENT& aEvent )
     D_PAD& masterPad = frame.GetDesignSettings().m_Pad_Master;
 
-    // can only export from a single pad
+    // can only copy from a single pad
     if( selection.Size() == 1 )
     {
@@ -342,7 +342,7 @@ int PAD_TOOL::pushPadSettings( const TOOL_EVENT& aEvent )
     {
         // multiple selected what to do?
-        // maybe master->selection? same as import multiple?
+        // maybe master->selection? same as apply multiple?
     }
 
diff --git a/pcbnew/tools/pad_tool.h b/pcbnew/tools/pad_tool.h
index 4d4458c41..1c0ffb4f8 100644
--- a/pcbnew/tools/pad_tool.h
+++ b/pcbnew/tools/pad_tool.h
@@ -50,11 +50,11 @@ public:
     void SetTransitions() override;
 
 private:
-    ///> Import pad settings from board design settings to a pad
-    int importPadSettings( const TOOL_EVENT& aEvent );
+    ///> Apply pad settings from board design settings to a pad
+    int applyPadSettings( const TOOL_EVENT& aEvent );
 
-    ///> Export pad settings from a pad to the board design settings
-    int exportPadSettings( const TOOL_EVENT& aEvent );
+    ///> Copy pad settings from a pad to the board design settings
+    int copyPadSettings( const TOOL_EVENT& aEvent );
 
     ///> Push pad settings from a pad to other pads on board or module
     int pushPadSettings( const TOOL_EVENT& aEvent );
-- 
2.11.0


Follow ups

References